document.addEventListener("DOMContentLoaded", function () {
    // Funnel Chart using CanvasJS
    var funnelChart = new CanvasJS.Chart("funnel_chart", {
        // theme: "light2",
        animationEnabled: true,
        data: [{
            type: "funnel",
            indexLabel: "{label} - {y}",
            toolTipContent: "<b>{label}</b>: {y}",
            dataPoints: [
                { label: "Step 1", y: 120 },
                { label: "Step 2", y: 100 },
                { label: "Step 3", y: 80 },
                { label: "Step 4", y: 60 },
                { label: "Step 5", y: 40 },
                { label: "Step 6", y: 20 }
            ]
        }]
    });
    funnelChart.render();

    // Stacked Bar Chart (Chart.js)
    var ctx = document.getElementById('stacked_barchart').getContext('2d');
    var stackedBarChart = new Chart(ctx, {
        type: 'bar',
        data: {
            labels: ['January', 'February', 'March', 'April'],
            datasets: [
                {
                    label: 'Dataset 1',
                    data: [40, 60, 80, 90,30], // Adjust values as needed
                    backgroundColor: '#FF9999'
                },
                {
                    label: 'Dataset 2',
                    data: [50, 60, 80, 100], // Adjust values as needed
                    backgroundColor: '#99FF99'
                },
                {
                    label: 'Dataset 3',
                    data: [60, 50, 100, 120], // Adjust values as needed
                    backgroundColor: '#9999FF'
                }
            ]
        },
        options: {
            responsive: true,
            plugins: {
                legend: {
                    position: 'top',
                },
            },
            scales: {
                x: {
                    stacked: true,
                },
                y: {
                    stacked: true,
                }
            }
        }
    });

    // Maximize Functionality
    const maximizeButtons = document.querySelectorAll('.btn-maximize');
    const maximizedCardContainer = document.getElementById('maximized-card-container');
    const maximizedCardTitle = document.getElementById('maximized-card-title');
    const maximizedChart = document.getElementById('maximized-chart').getContext('2d');
    let activeChartInstance;

    maximizeButtons.forEach(button => {
        button.addEventListener('click', function () {
            const card = this.closest('.card');
            const chartId = card.querySelector('canvas').id;
            const title = card.querySelector('.card-title').textContent;
            maximizedCardTitle.textContent = title;
            maximizedCardContainer.classList.remove('d-none');

            if (chartId === 'funnel_chart') {
                // Handle CanvasJS Funnel Chart
                activeChartInstance = new CanvasJS.Chart("maximized-chart", funnelChart.options);
                activeChartInstance.render();
            } else if (chartId === 'stacked_barchart') {
                // Handle Chart.js Stacked Bar Chart
                activeChartInstance = new Chart(maximizedChart, stackedBarChart.config);
            }
        });
    });

    // Close maximized chart
    document.querySelector('.btn-close').addEventListener('click', function () {
        maximizedCardContainer.classList.add('d-none');
        if (activeChartInstance) {
            activeChartInstance.destroy();
        }
    });
});
