// Manually register the Chart.js DataLabels plugin
Chart.register(ChartDataLabels);

// Data for Bar Chart (Top 5 Cities)
const cityData = {
    labels: ['Chennai', 'Delhi', 'Bangalore', 'Mumbai', 'Hyderabad'],
    datasets: [{
        label: 'Number of Assignments',
        data: [43, 30, 25, 20, 15],
        backgroundColor: ['#FF9999', '#FF9999', '#FF9999', '#FF9999', '#FF9999'],
        borderWidth: 1
    }]
};

// Data for Doughnut Charts (Top 5 Areas in Each City)
const areaData = {
    'Chennai': { 
        labels: ['Perungudi', 'Velachery', 'Adyar', 'Tambaram', 'Guindy'], 
        data: [10, 8, 7, 12, 8] 
    },
    'Delhi': { 
        labels: ['Connaught Place', 'Karol Bagh', 'Lajpat Nagar', 'Saket', 'Dwarka'], 
        data: [9, 11, 5, 7, 8] 
    },
    'Bangalore': { 
        labels: ['Whitefield', 'Koramangala', 'Indiranagar', 'Electronic City', 'Jayanagar'], 
        data: [8, 6, 9, 7, 8] 
    },
    'Mumbai': { 
        labels: ['Andheri', 'Bandra', 'Dadar', 'Goregaon', 'Borivali'], 
        data: [7, 5, 8, 10, 6] 
    },
    'Hyderabad': { 
        labels: ['Banjara Hills', 'Hitech City', 'Jubilee Hills', 'Madhapur', 'Secunderabad'], 
        data: [5, 6, 8, 4, 9] 
    }
};

// Data for Last 5 Days Leads
const leadsData = {
    labels: ['Day 1', 'Day 2', 'Day 3', 'Day 4', 'Day 5'],
    datasets: [{
        label: 'Leads',
        data: [50, 75, 60, 80, 90], 
        backgroundColor: '#FF66FF',
        borderWidth: 1
    }]
};

const chartInstances = {};

// Bar Chart for Top 5 Cities
const ctx1 = document.getElementById('chart1').getContext('2d');
chartInstances["chart1"] = new Chart(ctx1, {
    type: 'bar',
    data: cityData,
    options: {
        responsive: true,
        maintainAspectRatio: false, 
        plugins: {
            legend: { display: false },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: { weight: 'bold' },
                formatter: value => value
            },
            tooltip: { enabled: true }
        },
        onClick: (event, elements) => {
            if (elements.length > 0) {
                const index = elements[0].index;
                const cityName = cityData.labels[index];
                loadDoughnutChart(cityName);
                updateMap(cityName); // Add this line to update the map
            }
        }
    }
});

// Load Doughnut Chart for Selected City
function loadDoughnutChart(cityName) {
    const areaInfo = areaData[cityName];
    document.getElementById('chart2Title').innerText = `Top 5 Assignments by ${cityName}`;

    if (window.doughnutChart) {
        window.doughnutChart.destroy();
    }

    document.getElementById('chart2Card').style.display = 'block';

    const ctx2 = document.getElementById('chart2').getContext('2d');
    window.doughnutChart = new Chart(ctx2, {
        type: 'doughnut',
        data: {
            labels: areaInfo.labels,
            datasets: [{
                data: areaInfo.data,
                backgroundColor: ['#FFB266', '#CC6600', '#B266FF', '#CC00CC', '#FF99CC']
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false, 
            plugins:{
                legend: 
                {
                    display: true,
                    position: 'right',
                    labels: { boxWidth: 18 }
                },
                datalabels: {
                    color: '#000',
                    font: {
                        weight: 'bold', 
                        size: 13 
                    }
                }
            }
        }
    });

        // Force chart to resize
        window.doughnutChart.resize();
}

// Initially Shows Chennai
loadDoughnutChart ('Chennai');

// Bar Chart for Last 5 Days Leads
const ctxLeads = document.getElementById('leadsChart').getContext('2d');
const leadsChart = new Chart(ctxLeads, {
    type: 'bar',
    data: leadsData,
    options: {
        responsive: true,
        maintainAspectRatio: false, 
        plugins: {
            legend: { display: true },
            tooltip: { enabled: true }
        },
        scales: {
            y: {
                beginAtZero: true
            }
        }
    }
});

// Data for Freelancer By City and Area
const freelancerByCityData = {
    labels: ['Chennai', 'Delhi', 'Bangalore', 'Mumbai', 'Hyderabad'],
    datasets: [{
        label: 'Number of Freelancers',
        data: [23, 37, 15, 20, 10],
        backgroundColor: ['#99CCFF', '#99CCFF', '#99CCFF', '#99CCFF', '#99CCFF'],
        borderWidth: 1
    }]
};

// Area Data for Freelancers
const freelancerByAreaData = {
    'Chennai': { 
        labels: ['Perungudi', 'Velachery', 'Adyar', 'Tambaram', 'Guindy'], 
        data: [11, 3, 7, 9, 4] 
    },
    'Delhi': { 
        labels: ['Connaught Place', 'Karol Bagh', 'Lajpat Nagar', 'Saket', 'Dwarka'], 
        data: [4, 9, 11, 7, 3] 
    },
    'Bangalore': { 
        labels: ['Whitefield', 'Koramangala', 'Indiranagar', 'Electronic City', 'Jayanagar'], 
        data: [7, 3, 9, 11, 4] 
    },
    'Mumbai': { 
        labels: ['Andheri', 'Bandra', 'Dadar', 'Goregaon', 'Borivali'], 
        data: [3, 11, 6, 4, 9] 
    },
    'Hyderabad': { 
        labels: ['Banjara Hills', 'Hitech City', 'Jubilee Hills', 'Madhapur', 'Secunderabad'], 
        data: [9, 5, 3, 11, 6] 
    }
};

// Bar Chart for Freelancer By City
const ctxCity = document.getElementById('sf_city').getContext('2d');
const freelancerCityChart = new Chart(ctxCity, {
    type: 'bar',
    data: freelancerByCityData,
    options: {
        responsive: true,
        maintainAspectRatio: false, 
        plugins: {
            legend: { display: false },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: { weight: 'bold' },
                formatter: value => value
            },
            tooltip: { enabled: true }
        },
        onClick: (event, elements) => {
            if (elements.length > 0) {
                const index = elements[0].index;
                const cityName = freelancerByCityData.labels[index];
                updateFreelancerAreaChart(cityName);
                updateMap(cityName); // Add this line to update the map
            }
        }
    }
});

// Freelancer By Area Chart
function updateFreelancerAreaChart(cityName) {
    const areaInfo = freelancerByAreaData[cityName];
    const ctxArea = document.getElementById('sf_area').getContext('2d');

    if (window.freelancerAreaChart) {
        window.freelancerAreaChart.destroy();
    }

    window.freelancerAreaChart = new Chart(ctxArea, {
        type: 'bar',
        data: {
            labels: areaInfo.labels,
            datasets: [{
                label: 'Number of Freelancers',
                data: areaInfo.data,
                backgroundColor: ['#9933FF', '#9933FF', '#9933FF', '#9933FF', '#9933FF'],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false, 
            plugins: {
                legend: { display: false },
                datalabels: {
                    anchor: 'end',
                    align: 'top',
                    color: '#000',
                    font: { weight: 'bold' },
                    formatter: value => value
                },
                tooltip: { enabled: true }
            },
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
}

// Initially Shows Chennai
updateFreelancerAreaChart('Chennai');

// Function to initialize and update the map
var map = new OpenLayers.Map("mapdiv");
    map.addLayer(new OpenLayers.Layer.OSM());

    // Helper function for coordinate transformation
    function getLonLat(lon, lat) {
      return new OpenLayers.LonLat(lon, lat).transform(
        new OpenLayers.Projection("EPSG:4326"), // WGS 1984
        map.getProjectionObject() // Spherical Mercator
      );
    }

    // Create markers layer
    var markers = new OpenLayers.Layer.Markers("Markers");
    map.addLayer(markers);

    // Locations within Chennai (with latitude and longitude)
    var locations = [
      { name: "Perungudi", coords: [80.2483, 12.9604] },
      { name: "Guindy", coords: [80.2210, 13.0072] },
      { name: "Adyar", coords: [80.2612, 13.0068] },
      { name: "Velachery", coords: [80.2182, 12.9800] },
      { name: "Tambaram", coords: [80.1102, 12.9229] }
    ];

    // Add markers to the map for each location
    locations.forEach(location => {
      var lonLat = getLonLat(location.coords[0], location.coords[1]);
      var marker = new OpenLayers.Marker(lonLat);
      markers.addMarker(marker);
    });

    var zoom = 12;


    // Center the map on Chennai with an appropriate zoom level
    map.setCenter(getLonLat(80.2483, 12.9604), zoom); // Centered on Perungudi