// Manually register the chartjs datalabels plugin
Chart.register(ChartDataLabels);

const workPreferenceCtx = document.getElementById('work_preference');
const declinedReasonsCtx = document.getElementById('declined_reasons');
const maximizedChartCtx = document.getElementById('maximized-chart');

const workPreferenceData = {
    labels: ["Full Time", "Part Time", "Work Abroad", "Study Abroad"],
    datasets: [{
        label: 'No of Registrations',
        data: [10, 19, 8, 15, 8],
        backgroundColor: '#FF9999',
        borderColor: '#FF9999',
        borderWidth: 1,
        fill: false
    }]
};

const declinedReasonsData = {
    labels: ["Low Salary", "Location Issue", "Not Interested in Profile"],
    datasets: [{
        label: '# of Votes',
        data: [18, 3, 7],
        backgroundColor: '#39bda7',
        borderColor: '#39bda7',
        borderWidth: 1,
        fill: false
    }]
};

const chartOptions = {
    scales: {
        y: {
            beginAtZero: true
        }
    },
    plugins: {
        legend: {
            display: false
        },
        datalabels: {
            anchor: 'end',
            align: 'top',
            color: '#000',
            font: {
                weight: 'bold'
            },
            formatter: function (value) {
                return value;
            }
        }
    },
    responsive: true
};

const chartInstances = {};

// Initialize Charts
chartInstances["work_preference"] = new Chart(workPreferenceCtx, {
    type: 'bar',
    data: workPreferenceData,
    options: chartOptions
});

chartInstances["declined_reasons"] = new Chart(declinedReasonsCtx, {
    type: 'bar',
    data: declinedReasonsData,
    options: chartOptions
});

// Maximize Chart Functionality
document.querySelectorAll('.btn-maximize').forEach(button => {
    button.addEventListener('click', function () {
        const card = this.closest('.card');
        const title = card.querySelector('.card-title').innerText;
        const canvas = card.querySelector('canvas');
        const canvasId = canvas.id;

        document.getElementById('maximized-card-title').innerText = title;
        const maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');

        if (window.maximizedChartInstance) {
            window.maximizedChartInstance.destroy();
        }

        const originalChart = chartInstances[canvasId];
        const chartConfig = {
            type: originalChart.config.type,
            data: originalChart.config.data,
            options: originalChart.config.options
        };

        window.maximizedChartInstance = new Chart(maximizedChartCtx, chartConfig);
    });
});

document.querySelector('.btn-close').addEventListener('click', function () {
    const maximizedContainer = document.getElementById('maximized-card-container');
    maximizedContainer.classList.add('d-none');

    if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
    }
});
