// Manually register the Chart.js datalabels plugin
Chart.register(ChartDataLabels);

// Define colors for each year
var yearColors = {
    '2022': '#009999',
    '2023': '#FF6666',
    '2024': '#FFB266'
};

// Fetch data for Yearly Chart
$.ajax({
    url: 'yearly_data.json', 
    method: 'GET',
    success: function(response) {
        if (response.result === "success") {
            // Parse the response data for the chart
            var labels = response.list.map(item => item.year);
            var data = response.list.map(item => item.total);

            // Update the chart data
            chart1.data.labels = labels.filter(year => year !== 0); 
            chart1.data.datasets[0].data = data.filter((_, index) => labels[index] !== 0);
            chart1.data.datasets[0].backgroundColor = labels.filter(year => year !== 0).map(year => yearColors[year]);
            chart1.update();

            // Initialize the summary card with the latest year
            updateSummaryCard1(labels[labels.length - 1]);
        }
    },
    error: function(error) {
        console.error('Error fetching data:', error);
    }
});

// Chart 1 (Yearly Data)
var chart1Data = {
    labels: [],
    datasets: [{
        label: 'Count',
        data: [],
        backgroundColor: [],
        borderColor: [
            '#009999',
            '#FF6666',
            '#FFB266'
        ],
        borderWidth: 1
    }]
};

var chart1Options = {
    onClick: function(event, elements) {
        if (elements.length > 0) {
            var clickedIndex = elements[0].index;
            var clickedYear = chart1.data.labels[clickedIndex];

            // Ensure the clicked year is valid before proceeding
            if (clickedYear) {
                loadChart2(clickedYear); 
                updateSummaryCard1(clickedYear); 
            }
        }
    },
    responsive: true,
    maintainAspectRatio: false,
    plugins: {
        legend: {
            display: false
        },
        datalabels: {
            anchor: 'end',
            align: 'top',
            color: '#000',
            font: {
                weight: 'bold'
            },
            formatter: function(value) {
                return value;
            }
        }
    }
};

var chart1Ctx = document.getElementById('chart1').getContext('2d');
var chart1 = new Chart(chart1Ctx, {
    type: 'bar',
    data: chart1Data,
    options: chart1Options
});
// Load the initial Summary card in Yearly chart
updateSummaryCard1('2022');


// Function to update the Yearly Summary Card
function updateSummaryCard1(year) {
    $.ajax({
        url: 'yearly_summary.json', 
        method: 'GET',
        success: function(response) {
            if (response.result === "success") {
                var selectedYearData = response.data.find(item => item.year == year);

                if (selectedYearData) {
                    var summaryCard1 = document.getElementById('summaryCard1');

                    // Update the summary card content
                    summaryCard1.innerHTML = `
                        <h5 class="card-title">Yearly Summary for ${year}</h5>
                        <p>Average Attendance: ${selectedYearData.averageAttendance}</p>
                        <p>Total Teachers Attended: ${selectedYearData.totalTeachers}</p>
                        <p>Total Classroom Sessions: ${selectedYearData.totalSessions}</p>
                    `;
                }
            }
        },
        error: function(error) {
            console.error('Error fetching summary card data:', error);
        }
    });
}

// Function to load Chart 2 (Quarterly Data)
function loadChart2(year) {
    // Remove existing Chart 2 and Chart 3 containers if they exist
    var existingChart2Container = document.getElementById('chart2');
    if (existingChart2Container) {
        existingChart2Container.remove();
    }

    var existingChart3Container = document.getElementById('chart3');
    if (existingChart3Container) {
        existingChart3Container.remove();
    }

    // Fetch quarterly data 
    $.ajax({
        url: 'quarterly_data.json', 
        method: 'GET',
        success: function(response) {
            if (response.result === "success") {
                // Filter the data to include only the selected year for quarterly data
                var filteredData = response.list.filter(item => item.year === year);
                var quarterlyData = filteredData.map(item => item.total);
                var quarters = filteredData.map(item => 'Q' + item.quarter);

                if (filteredData.length === 0) {
                    alert(`No data found for the year ${year}`);
                    return;
                }
                
                var newChartId = 'chart2';
                var newChartContainer = document.createElement('div');
                newChartContainer.classList.add('col-lg-12', 'grid-margin', 'stretch-card');
                newChartContainer.id = newChartId;  
                newChartContainer.innerHTML = `
                    <div class="card">
                        <div class="card-title-container">
                            <h4 class="card-title">Quarterly Data for ${year}</h4>
                        </div>
                        <div class="card-body">
                            <div id="summaryCard2_${year}" class="summary-card">
                                <h5 class="card-title">Quarterly Summary for ${year}</h5>
                                <p>Average Attendance: --</p>
                                <p>Total Teachers Attended: --</p>
                                <p>Total Classroom Sessions: --</p>
                            </div>
                            <div class="chart-container">
                                <canvas id="${newChartId}_canvas"></canvas>
                            </div>
                        </div>
                    </div>
                `;
                document.querySelector('.content-wrapper').appendChild(newChartContainer);

                var chart2Data = {
                    labels: quarters, 
                    datasets: [{
                        label: 'Count',
                        data: quarterlyData, 
                        backgroundColor: yearColors[year],
                        borderColor: yearColors[year].replace('0.6', '1'),  
                        borderWidth: 1
                    }]
                };

                var chart2Options = {
                    onClick: function(event, elements) {
                        if (elements.length > 0) {
                            var clickedQuarter = chart2Data.labels[elements[0].index];
                            loadChart3(year, clickedQuarter);
                            updateSummaryCard2(year, clickedQuarter);
                        }
                    },
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            display: false
                        },
                        datalabels: {
                            anchor: 'end',
                            align: 'top',
                            color: '#000',
                            font: {
                                weight: 'bold'
                            },
                            formatter: function(value) {
                                return value;
                            }
                        }
                    }
                };

                var chart2Ctx = document.getElementById(`${newChartId}_canvas`).getContext('2d');
                new Chart(chart2Ctx, {
                    type: 'bar',
                    data: chart2Data,
                    options: chart2Options
                });

                // Display the summary for the first quarter by default
                if (filteredData.length > 0) {
                    var firstQuarter = 'Q' + filteredData[0].quarter;
                    updateSummaryCard2(year, firstQuarter);
                }

                // Scroll the new chart container into view
                newChartContainer.scrollIntoView({ behavior: 'smooth', block: 'start' });
            }
        },
        error: function(error) {
            console.error('Error fetching quarterly data:', error);
        }
    });
}

// Function to update the Quarterly Summary Card
function updateSummaryCard2(year, quarter) {
    $.ajax({
        url: 'quarterly_summary_data.json', 
        method: 'GET',
        success: function(response) {
            if (response.result === "success") {
                // Extract the summary data for the given year and quarter data
                var summaryData = response.data[year] && response.data[year][quarter];
                
                if (summaryData) {
                    // Update the summary card with the fetched data
                    var summaryCard2 = document.getElementById('summaryCard2_' + year);
                    summaryCard2.innerHTML = `
                        <h5 class="card-title">Quarterly Summary for ${quarter} (${year})</h5>
                        <p>Average Attendance: ${summaryData.attendance}</p>
                        <p>Total Teachers Attended: ${summaryData.teachers}</p>
                        <p>Total Classroom Sessions: ${summaryData.sessions}</p>
                    `;
                } else {
                    console.error(`No summary data found for ${quarter} (${year})`);
                }
            }
        },
        error: function(error) {
            console.error('Error fetching summary data:', error);
        }
    });
}


// Function to load Chart 3 (Monthly Data)
function loadChart3(year, quarter) {
    // Remove existing Chart 3 container if it exists
    var existingChart3Container = document.getElementById('chart3');
    if (existingChart3Container) {
        existingChart3Container.remove();
    }

    var newChartId = 'chart3';
    var newChartContainer = document.createElement('div');
    newChartContainer.classList.add('col-lg-12', 'grid-margin', 'stretch-card');
    newChartContainer.id = newChartId;  
    newChartContainer.innerHTML = `
        <div class="card">
            <div class="card-title-container">
                <h4 class="card-title">Monthly Data for ${quarter} (${year})</h4>
            </div>
            <div class="card-body">
                <div id="summaryCard3_${year}_${quarter}" class="summary-card">
                    <h5 class="card-title">Monthly Summary for ${quarter} (${year})</h5>
                    <!-- Monthly Summary Card will be updated by the updateSummaryCard3 function -->
                </div>
                <div class="chart-container">
                    <canvas id="${newChartId}_canvas"></canvas>
                </div>
            </div>
        </div>
    `;
    document.querySelector('.content-wrapper').appendChild(newChartContainer);

    // Months for Q1,Q2,Q3,Q4
    var quarterMonths = {
        "Q1": [1, 2, 3],   // Jan, Feb, Mar
        "Q2": [4, 5, 6],   // Apr, May, Jun
        "Q3": [7, 8, 9],   // Jul, Aug, Sep
        "Q4": [10, 11, 12] // Oct, Nov, Dec
    };

    // Fetch monthly data using AJAX GET request
    $.ajax({
        url: 'monthly_data.json', 
        method: 'GET',
        success: function(response) {
            if (response.result === "success") {
                // Filter the monthly data for the selected year and quarter
                var monthlyData = response.list.filter(item => item.year === year);
                var months = quarterMonths[quarter].map(monthNumber => {
                    // Convert month number to month name
                    return new Date(year, monthNumber - 1).toLocaleString('default', { month: 'short' });
                });

                // Map data to corresponding months
                var data = months.map(month => {
                    var monthNumber = new Date(Date.parse(month +" 1, 2012")).getMonth() + 1; // Get month number (1-12)
                    var item = monthlyData.find(data => data.month === monthNumber);
                    return item ? item.total : 0; // Default to 0 if no data available
                });

                var chart3Data = {
                    labels: months,
                    datasets: [{
                        label: 'Count',
                        data: data,
                        backgroundColor: yearColors[year],
                        borderColor: yearColors[year].replace('0.6', '1'),
                        borderWidth: 1
                    }]
                };

                var chart3Options = {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            display: false
                        },
                        datalabels: {
                            anchor: 'end',
                            align: 'top',
                            color: '#000',
                            font: {
                                weight: 'bold'
                            },
                            formatter: function(value) {
                                return value;
                            }
                        }
                    },
                    onClick: function(event, elements) {
                        if (elements.length > 0) {
                            var clickedMonth = chart3Data.labels[elements[0].index];
                            updateSummaryCard3(year, quarter, clickedMonth);
                        }
                    }
                };

                var chart3Ctx = document.getElementById(`${newChartId}_canvas`).getContext('2d');
                new Chart(chart3Ctx, {
                    type: 'bar',
                    data: chart3Data,
                    options: chart3Options
                });

                // Update the summary card with the initial data
                updateSummaryCard3(year, quarter, months[0]);

                // Scroll the new chart container into view
                newChartContainer.scrollIntoView({ behavior: 'smooth', block: 'start' });
            }
        },
        error: function(error) {
            console.error('Error fetching monthly data:', error);
        }
    });
}

// Function to update the Monthly Summary Card
function updateSummaryCard3(year, quarter, month) {
    // Fetch the summary data using AJAX GET request
    $.ajax({
        url: 'monthly_summary.json', 
        method: 'GET',
        success: function(response) {
            if (response[year] && response[year][quarter] && response[year][quarter][month]) {
                var summaryData = response[year][quarter][month];
                
                var summaryCard3 = document.getElementById('summaryCard3_' + year + '_' + quarter);
                summaryCard3.innerHTML = `
                    <h5 class="card-title">Monthly Summary for ${month} (${quarter}, ${year})</h5>
                    <p>Average Attendance: ${summaryData.attendance}</p>
                    <p>Total Teachers Attended: ${summaryData.teachers}</p>
                    <p>Total Classroom Sessions: ${summaryData.sessions}</p>
                `;
            } else {
                console.error('No summary data available for:', year, quarter, month);
                var summaryCard3 = document.getElementById('summaryCard3_' + year + '_' + quarter);
                summaryCard3.innerHTML = `
                    <h5 class="card-title">Monthly Summary for ${month} (${quarter}, ${year})</h5>
                    <p>Data not available.</p>
                `;
            }
        },
        error: function(error) {
            console.error('Error fetching summary data:', error);
            var summaryCard3 = document.getElementById('summaryCard3_' + year + '_' + quarter);
            summaryCard3.innerHTML = `
                <h5 class="card-title">Monthly Summary for ${month} (${quarter}, ${year})</h5>
                <p>Error fetching data.</p>
            `;
        }
    });
}


var pie_data = [10, 20, 30, 40, 50, 60]; 
var pie_labels = ['Category 1', 'Category 2', 'Category 3', 'Category 4', 'Category 5', 'Category 6'];


var doughnutPieData = {
    datasets: [{
        data: pie_data,
        backgroundColor: ['#CCFF99', '#CCCCFF', '#FF9999', '#B266FF', '#CC00CC', '#FFB266'],
        borderColor: ['#CCFF99', '#CCCCFF', '#FF9999', '#B266FF', '#CC00CC', '#FFB266']
    }],
    labels: pie_labels
};

var doughnutPieOptions = {
    responsive: true,
    animation: {
        animateScale: true,
        animateRotate: true
    },
    plugins: {
        legend: {
            display: true,
            position: 'right',
            labels: { boxWidth: 15 }
        }
    }
};

var pieChartCtx = document.getElementById('pieChart').getContext('2d');
var pieChart = new Chart(pieChartCtx, {
    type: 'pie',
    data: doughnutPieData,
    options: doughnutPieOptions
});
