// Manually register the Chart.js datalabels plugin
Chart.register(ChartDataLabels);

// Define colors for each year
var yearColors = {
    '2022': '#009999',
    '2023': '#FF6666',
    '2024': '#FFB266'
};

// Data and configuration for Chart 1 (Yearly Data)
var chart1Data = {
    labels: ['2022', '2023', '2024'],
    datasets: [{
        label: 'Count',
        data: [120, 150, 185],
        backgroundColor: [
            yearColors['2022'],
            yearColors['2023'],
            yearColors['2024']
        ],
        borderColor: [
            '#009999',
            '#FF6666',
            '#FFB266'
        ],
        borderWidth: 1
    }]
};

var chart1Options = {
    onClick: function(event, elements) {
        if (elements.length > 0) {
            var clickedYear = chart1Data.labels[elements[0].index];
            loadChart2(clickedYear);
            updateSummaryCard1(clickedYear);
        }
    },
    responsive: true,
    maintainAspectRatio: false,
    plugins: {
        legend: {
            display: false
        },
        datalabels: {
            anchor: 'end',
            align: 'top',
            color: '#000',
            font: {
                weight: 'bold'
            },
            formatter: function(value) {
                return value;
            }
        }
    }
};

var chart1Ctx = document.getElementById('chart1').getContext('2d');
var chart1 = new Chart(chart1Ctx, {
    type: 'bar',
    data: chart1Data,
    options: chart1Options
});

// Function to update the Yearly Summary Card
function updateSummaryCard1(year) {
    var summaryCard1 = document.getElementById('summaryCard1');
    summaryCard1.innerHTML = `
        <h5 class="card-title">Yearly Summary for ${year}</h5>
        <p>Average Attendance: ${year === '2022' ? '85%' : year === '2023' ? '88%' : '90%'}</p>
        <p>Total Teachers Attended: ${year === '2022' ? '300' : year === '2023' ? '320' : '340'}</p>
        <p>Total Classroom Sessions: ${year === '2022' ? '50' : year === '2023' ? '55' : '60'}</p>
    `;
}


// Function to load Chart 2 (Quarterly Data)
function loadChart2(year) {
    // Remove existing Chart 2 and Chart 3 containers if they exist
    var existingChart2Container = document.getElementById('chart2');
    if (existingChart2Container) {
        existingChart2Container.remove();
    }

    var existingChart3Container = document.getElementById('chart3');
    if (existingChart3Container) {
        existingChart3Container.remove();
    }

    var quarterlyData = {
        '2022': [20, 36, 41],
        '2023': [35, 45, 55],
        '2024': [38, 45, 56]
    };

    // Create a new chart container dynamically
    var newChartId = 'chart2';
    var newChartContainer = document.createElement('div');
    newChartContainer.classList.add('col-lg-12', 'grid-margin', 'stretch-card');
    newChartContainer.id = newChartId;  // Assign an ID to the container
    newChartContainer.innerHTML = `
        <div class="card">
            <div class="card-title-container">
                <h4 class="card-title">Quarterly Data for ${year}</h4>
            </div>
            <div class="card-body">
                <div id="summaryCard2_${year}" class="summary-card">
                    <h5 class="card-title">Quarterly Summary for ${year}</h5>
                    <p>Average Attendance: --</p>
                    <p>Total Teachers Attended: --</p>
                    <p>Total Classroom Sessions: --</p>
                </div>
                <div class="chart-container">
                    <canvas id="${newChartId}_canvas"></canvas>
                </div>
            </div>
        </div>
    `;
    document.querySelector('.content-wrapper').appendChild(newChartContainer);

    var chart2Data = {
        labels: ['Q1', 'Q2', 'Q3'],
        datasets: [{
            label: 'Count',
            data: quarterlyData[year],
            backgroundColor: yearColors[year],
            borderColor: yearColors[year].replace('0.6', '1'),  // Change transparency for border
            borderWidth: 1
        }]
    };

    var chart2Options = {
        onClick: function(event, elements) {
            if (elements.length > 0) {
                var clickedQuarter = chart2Data.labels[elements[0].index];
                loadChart3(year, clickedQuarter);
                updateSummaryCard2(year, clickedQuarter);
            }
        },
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            legend: {
                display: false
            },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: {
                    weight: 'bold'
                },
                formatter: function(value) {
                    return value;
                }
            }
        }
    };

    var chart2Ctx = document.getElementById(`${newChartId}_canvas`).getContext('2d');
    new Chart(chart2Ctx, {
        type: 'bar',
        data: chart2Data,
        options: chart2Options
    });

    // Scroll the new chart container into view
    newChartContainer.scrollIntoView({ behavior: 'smooth', block: 'start' });
}

// Function to update the Quarterly Summary Card
function updateSummaryCard2(year, quarter) {
    var summaryCard2 = document.getElementById('summaryCard2_' + year);
    summaryCard2.innerHTML = `
        <h5 class="card-title">Quarterly Summary for ${quarter} (${year})</h5>
        <p>Average Attendance: ${quarter === 'Q1' ? '82%' : quarter === 'Q2' ? '85%' : '87%'}</p>
        <p>Total Teachers Attended: ${quarter === 'Q1' ? '150' : quarter === 'Q2' ? '160' : '170'}</p>
        <p>Total Classroom Sessions: ${quarter === 'Q1' ? '15' : quarter === 'Q2' ? '20' : '25'}</p>
    `;
}

// Function to load Chart 3 (Monthly Data)
function loadChart3(year, quarter) {
    // Remove existing Chart 3 container if it exists
    var existingChart3Container = document.getElementById('chart3');
    if (existingChart3Container) {
        existingChart3Container.remove();
    }

    var monthlyData = {
        'Q1': [10, 18, 27, 41],
        'Q2': [15, 23, 32, 42],
        'Q3': [22, 30, 38, 47],
        'Q4': [26, 32, 43, 51]
    };

    // Create a new chart container dynamically
    var newChartId = 'chart3';
    var newChartContainer = document.createElement('div');
    newChartContainer.classList.add('col-lg-12', 'grid-margin', 'stretch-card');
    newChartContainer.id = newChartId;  // Assign an ID to the container
    newChartContainer.innerHTML = `
        <div class="card">
            <div class="card-title-container">
                <h4 class="card-title">Monthly Data for ${quarter} (${year})</h4>
            </div>
            <div class="card-body">
                <div id="summaryCard3_${year}_${quarter}" class="summary-card">
                    <h5 class="card-title">Monthly Summary for ${quarter} (${year})</h5>
                    <!-- Monthly Summary Card will be updated by the updateSummaryCard3 function -->
                </div>
                <div class="chart-container">
                    <canvas id="${newChartId}_canvas"></canvas>
                </div>
            </div>
        </div>
    `;
    document.querySelector('.content-wrapper').appendChild(newChartContainer);

    var chart3Data = {
        labels: ['Jan', 'Feb', 'Mar', 'Apr'],
        datasets: [{
            label: 'Count',
            data: monthlyData[quarter],
            backgroundColor: yearColors[year],
            borderColor: yearColors[year].replace('0.6', '1'),
            borderWidth: 1
        }]
    };

    var chart3Options = {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            legend: {
                display: false
            },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: {
                    weight: 'bold'
                },
                formatter: function(value) {
                    return value;
                }
            }
        },
        onClick: function(event, elements) {
            if (elements.length > 0) {
                var clickedMonth = chart3Data.labels[elements[0].index];
                updateSummaryCard3(year, quarter, clickedMonth);
            }
        }
    };

    var chart3Ctx = document.getElementById(`${newChartId}_canvas`).getContext('2d');
    new Chart(chart3Ctx, {
        type: 'bar',
        data: chart3Data,
        options: chart3Options
    });

    // Update the summary card with the initial data
    updateSummaryCard3(year, quarter, 'Jan');

    // Scroll the new chart container into view
    newChartContainer.scrollIntoView({ behavior: 'smooth', block: 'start' });
}

// Function to update the Monthly Summary Card
function updateSummaryCard3(year, quarter, month) {
    var summaryCard3 = document.getElementById('summaryCard3_' + year + '_' + quarter);
    summaryCard3.innerHTML = `
        <h5 class="card-title">Monthly Summary for ${month} (${quarter}, ${year})</h5>
        <p>Average Attendance: ${month === 'Jan' ? '78%' : month === 'Feb' ? '80%' : month === 'Mar' ? '82%' : '85%'}</p>
        <p>Total Teachers Attended: ${month === 'Jan' ? '90' : month === 'Feb' ? '95' : month === 'Mar' ? '100' : '110'}</p>
        <p>Total Classroom Sessions: ${month === 'Jan' ? '12' : month === 'Feb' ? '14' : month === 'Mar' ? '16' : '18'}</p>
    `;
}

// Initialize the Yearly Chart
function initializeCharts() {
    var chart1Container = document.createElement('div');
    chart1Container.classList.add('col-lg-12', 'grid-margin', 'stretch-card');
    chart1Container.id = 'chart1';  // Assign an ID to the container
    chart1Container.innerHTML = `
        <div class="card">
            <div class="card-body">
                <div class="card-title-container">
                    <h4 class="card-title">Yearly Data</h4>
                </div>
                <div class="chart-container">
                    <canvas id="chart1_canvas"></canvas>
                </div>
                <div id="summaryCard1" class="summary-card">
                    <h5 class="card-title">Yearly Summary</h5>
                    <p>Average Attendance: --</p>
                    <p>Total Teachers Attended: --</p>
                    <p>Total Classroom Sessions: --</p>
                </div>
            </div>
        </div>
    `;
    document.querySelector('.content-wrapper').appendChild(chart1Container);
}

// Load the initial Yearly Chart and Summary Card
updateSummaryCard1('2022');
