$(function() {
    /* ChartJS
     * -------
     * Data and config for chartjs
     */
    'use strict';

    var shk_cities_data = {
        datasets: [{
          data: [20, 30, 25, 40, 35],
          backgroundColor: ['#CCFF99', '#CCCCFF', '#FF9999', '#B266FF', '#CC00CC'],      
          borderColor: ['#CCFF99', '#CCCCFF', '#FF9999', '#B266FF', '#CC00CC']
        }],
        labels: ['Chennai', 'Bangalore', 'Delhi', 'Mumbai', 'Pune']       //, 'Kolkata', 'Ahmedabad', 'Patna', 'Haryana', 'Punjab', 'Gujarat'
      };
    
      var shk_cities_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };

      var shk_qualification_data = {
        labels: ["Post Graduate", "Graduate", "12th Pass", "10th Pass"],
        datasets: [{
          label: '# of Votes',
          data: [3, 17, 7, 12],
          backgroundColor: ['#3399FF', '#3399FF', '#3399FF', '#3399FF'],
          borderColor: ['#3399FF', '#3399FF', '#3399FF', '#3399FF'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var shk_qualification_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };
  
      var shk_earnings_data = {
        datasets: [{
          data: [30, 40, 30],
          backgroundColor: ['#FF6666', '#CC0000', '#FFCCCC'],
          borderColor: ['#FF6666', '#CC0000', '#FFCCCC']
        }],
        labels: ['Top 1', 'Top 2', 'Top 3']
      };
    
      var shk_earnings_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };
  


    
    var chartInstances = {};
  
    function initializeChart(chartId, chartType, chartData, chartOptions) {
      var ctx = $(chartId).get(0).getContext("2d");
      return new Chart(ctx, {
        type: chartType,
        data: chartData,
        options: chartOptions
      });
    }
  
    if ($("#shk_cities").length) {
        chartInstances["shk_cities"] = initializeChart("#shk_cities", 'pie', shk_cities_data, shk_cities_options);
    }
  
    if ($("#shk_qualification").length) {
      chartInstances["shk_qualification"] = initializeChart("#shk_qualification", 'horizontalBar', shk_qualification_data, shk_qualification_options);
    }
  
    if ($("#shk_earnings").length) {
        chartInstances["shk_earnings"] = initializeChart("#shk_earnings", 'doughnut', shk_earnings_data, shk_earnings_options);
    }


    document.querySelectorAll('.btn-maximize').forEach(button => {
      button.addEventListener('click', function() {
        var card = this.closest('.card');
        var title = card.querySelector('.card-title').innerText;
        var canvas = card.querySelector('canvas');
        var canvasId = canvas.id;
  
        document.getElementById('maximized-card-title').innerText = title;
  
        var maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');
  
        if (window.maximizedChartInstance) {
          window.maximizedChartInstance.destroy();
        }
  
        var originalChart = chartInstances[canvasId];
        var chartConfig = {
          type: originalChart.config.type,
          data: originalChart.config.data,
          options: originalChart.config.options
        };
  
        var maximizedChartCanvas = document.getElementById('maximized-chart').getContext('2d');
        window.maximizedChartInstance = new Chart(maximizedChartCanvas, chartConfig);
      });
    });
  
    document.querySelector('.btn-close').addEventListener('click', function() {
      var maximizedContainer = document.getElementById('maximized-card-container');
      maximizedContainer.classList.add('d-none');
  
      if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
      }
    });
    
  });
  