$(function() {
    /* ChartJS
     * -------
     * Data and config for chartjs
     */
    'use strict';

    var reg_cities_data = {
        datasets: [{
          data: [23, 40, 30, 37, 35],
          backgroundColor: ['#33FFFF', '#FF007F', '#CC00CC', '#FFFF66', '#CC0000'],      
          borderColor: ['#33FFFF', '#FF007F', '#CC00CC', '#FFFF66', '#CC0000']
        }],
        labels: ['Chennai', 'Bangalore', 'Delhi', 'Mumbai', 'Pune']       //, 'Kolkata', 'Ahmedabad', 'Patna', 'Haryana', 'Punjab', 'Gujarat'
      };
    
      var reg_cities_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };


      var gender_ratio_data = {
        datasets: [{
          data: [20, 35],
          backgroundColor: ['#66B2FF', '#004C99'],
          borderColor: ['#66B2FF', '#004C99']
        }],
        labels: ['Male', 'Female']
      };
    
      var gender_ratio_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };


      var reg_app_data = {
        labels: ["Registration", "Application"],
        datasets: [{
          label: '# of Votes',
          data: [13, 10, 5],
          backgroundColor: ['#66FF66', '#009900'],
          borderColor: ['#66FF66', '#009900'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var reg_app_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };
  
      
      var app_withdrawal_data = {
        datasets: [{
          data: [30, 15],
          backgroundColor: ['#FF66FF', '#990099'],
          borderColor: ['#FF66FF', '#990099']
        }],
        labels: ['Application', 'Withdrawal']
      };
    
      var app_withdrawal_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };

        
      var withdrawal_reason_data = {
        labels: ["One", "Two", "Three"],
        datasets: [{
          label: '# of Votes',
          data: [10, 13, 7, 0],
          backgroundColor: ['#990099', '#990099', '#990099'],
          borderColor: ['#990099', '#990099', '#990099'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var withdrawal_reason_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };


      var client_decline_data = {
        labels: ["One", "Two", "Three"],
        datasets: [{
          label: 'No of Registrations',
          data: [10, 19, 8],
          backgroundColor: ['#009999', '#009999', '#009999'],
          borderColor: ['#009999', '#009999', '#009999'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var client_decline_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };

      
    var chartInstances = {};
  
    function initializeChart(chartId, chartType, chartData, chartOptions) {
      var ctx = $(chartId).get(0).getContext("2d");
      return new Chart(ctx, {
        type: chartType,
        data: chartData,
        options: chartOptions
      });
    }
  
    if ($("#reg_cities").length) {
        chartInstances["reg_cities"] = initializeChart("#reg_cities", 'pie', reg_cities_data, reg_cities_options);
    }

    if ($("#gender_ratio").length) {
        chartInstances["gender_ratio"] = initializeChart("#gender_ratio", 'doughnut', gender_ratio_data, gender_ratio_options);
    }
  
    if ($("#reg_app").length) {
      chartInstances["reg_app"] = initializeChart("#reg_app", 'horizontalBar', reg_app_data, reg_app_options);
    }

    if ($("#app_withdrawal").length) {
        chartInstances["app_withdrawal"] = initializeChart("#app_withdrawal", 'doughnut', app_withdrawal_data, app_withdrawal_options);
    }
  
    if ($("#withdrawal_reason").length) {
      chartInstances["withdrawal_reason"] = initializeChart("#withdrawal_reason", 'horizontalBar', withdrawal_reason_data, withdrawal_reason_options);
    }

    if ($("#client_decline").length) {
        chartInstances["client_decline"] = initializeChart("#client_decline", 'bar', client_decline_data, client_decline_options);
    }
  

    document.querySelectorAll('.btn-maximize').forEach(button => {
      button.addEventListener('click', function() {
        var card = this.closest('.card');
        var title = card.querySelector('.card-title').innerText;
        var canvas = card.querySelector('canvas');
        var canvasId = canvas.id;
  
        document.getElementById('maximized-card-title').innerText = title;
  
        var maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');
  
        if (window.maximizedChartInstance) {
          window.maximizedChartInstance.destroy();
        }
  
        var originalChart = chartInstances[canvasId];
        var chartConfig = {
          type: originalChart.config.type,
          data: originalChart.config.data,
          options: originalChart.config.options
        };
  
        var maximizedChartCanvas = document.getElementById('maximized-chart').getContext('2d');
        window.maximizedChartInstance = new Chart(maximizedChartCanvas, chartConfig);
      });
    });
  
    document.querySelector('.btn-close').addEventListener('click', function() {
      var maximizedContainer = document.getElementById('maximized-card-container');
      maximizedContainer.classList.add('d-none');
  
      if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
      }
    });
    
  });
  