$(function() {
    /* ChartJS
     * -------
     * Data and config for chartjs
     */
    'use strict';

    var top5_states_data = {
        datasets: [{
          data: [30, 25, 18, 15, 12],
          backgroundColor: ['#CCCC00', '#00994C', '#FF8000', '#FFFF99', '#CC0000'],      
          borderColor: ['#CCCC00', '#00994C', '#FF8000', '#FFFF99', '#CC0000']
        }],
        labels: ['Tamil Nadu', 'Andhra Pradesh', 'Telangana', 'Assam', 'Maharashtra']      
      };
    
      var top5_states_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };


      var top5_cities_data = {
        labels: ['Delhi', 'Bangalore', 'Chennai', 'Mumbai', 'Pune'],
        datasets: [{
          // label: 'No of Registrations',
          data: [19, 10, 9, 7, 5],
          backgroundColor: ['#D3978F', '#D3978F', '#D3978F', '#D3978F', '#D3978F'],          
          borderColor: ['#D3978F', '#D3978F', '#D3978F', '#D3978F', '#D3978F'],              
          borderWidth: 1,
          fill: false
        }]
      };
    
      var top5_cities_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };


      var top5_qualifications_data = {
        datasets: [{
          data: [40, 35, 25, 20, 18],
          backgroundColor: ['#CC99FF', '#9933FF', '#6600CC', '#00CCCC', '#006666'],
          borderColor: ['#CC99FF', '#9933FF', '#6600CC', '#00CCCC', '#006666']
        }],
        labels: ['Graduate', 'Diploma', '12th Pass', '10th Pass', 'Post Graduate']
      };
    
      var top5_qualifications_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };

      var gender_ratio_data = {
        datasets: [{
          data: [25, 45],
          backgroundColor: ['#FF66FF', '#CC0066'],
          borderColor: ['#FF66FF', '#CC0066']
        }],
        labels: ['Male', 'Female']
      };
    
      var gender_ratio_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };

        
      var top5_source_data = {
        labels: ["IBM", "Facebook", "Twitter", "WhatsApp", "Instagram"],
        datasets: [{
          // label: '# of Sources',
          data: [13, 10, 9, 7, 5, 0],
          backgroundColor: ['#FF6666', '#FF6666', '#FF6666', '#FF6666', '#FF6666'],
          borderColor: ['#FF6666', '#FF6666', '#FF6666', '#FF6666', '#FF6666'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var top5_source_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };

      
      
    var chartInstances = {};
  
    function initializeChart(chartId, chartType, chartData, chartOptions) {
      var ctx = $(chartId).get(0).getContext("2d");
      return new Chart(ctx, {
        type: chartType,
        data: chartData,
        options: chartOptions
      });
    }
  
    if ($("#top5_states").length) {
        chartInstances["top5_states"] = initializeChart("#top5_states", 'pie', top5_states_data, top5_states_options);
    }

    if ($("#top5_cities").length) {
        chartInstances["top5_cities"] = initializeChart("#top5_cities", 'bar', top5_cities_data, top5_cities_options);
    }
    
    if ($("#top5_qualifications").length) {
        chartInstances["top5_qualifications"] = initializeChart("#top5_qualifications", 'doughnut', top5_qualifications_data, top5_qualifications_options);
    }

    if ($("#gender_ratio").length) {
        chartInstances["gender_ratio"] = initializeChart("#gender_ratio", 'doughnut', gender_ratio_data, gender_ratio_options);
    }

    if ($("#top5_source").length) {
      chartInstances["top5_source"] = initializeChart("#top5_source", 'horizontalBar', top5_source_data, top5_source_options);
    }

    
  

    document.querySelectorAll('.btn-maximize').forEach(button => {
      button.addEventListener('click', function() {
        var card = this.closest('.card');
        var title = card.querySelector('.card-title').innerText;
        var canvas = card.querySelector('canvas');
        var canvasId = canvas.id;
  
        document.getElementById('maximized-card-title').innerText = title;
  
        var maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');
  
        if (window.maximizedChartInstance) {
          window.maximizedChartInstance.destroy();
        }
  
        var originalChart = chartInstances[canvasId];
        var chartConfig = {
          type: originalChart.config.type,
          data: originalChart.config.data,
          options: originalChart.config.options
        };
  
        var maximizedChartCanvas = document.getElementById('maximized-chart').getContext('2d');
        window.maximizedChartInstance = new Chart(maximizedChartCanvas, chartConfig);
      });
    });
  
    document.querySelector('.btn-close').addEventListener('click', function() {
      var maximizedContainer = document.getElementById('maximized-card-container');
      maximizedContainer.classList.add('d-none');
  
      if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
      }
    });
    
  });
  