$(function() {
    /* ChartJS
     * -------
     * Data and config for chartjs
     */
    'use strict';

    var msme_cities_data = {
        datasets: [{
          data: [20, 30, 25, 40, 35],
          backgroundColor: ['#FF3333', '#0080FF', '#99FF33', '#FF007F', '#99CCFF'],      
          borderColor: ['#FF3333', '#0080FF', '#99FF33', '#FF007F', '#99CCFF']
        }],
        labels: ['Chennai', 'Bangalore', 'Delhi', 'Mumbai', 'Pune']       //, 'Kolkata', 'Ahmedabad', 'Patna', 'Haryana', 'Punjab', 'Gujarat'
      };
    
      var msme_cities_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };

  
      var msme_category_data = {
        datasets: [{
          data: [30, 40, 30],
          backgroundColor: ['#33FF99', '#009900', '#006633'],
          borderColor: ['#33FF99', '#009900', '#006633']
        }],
        labels: ['One', 'Two', 'Three']
      };
    
      var msme_category_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };
  

      var msme_feedback_data = {
        labels: ["One", "Two", "Three", "Four"],
        datasets: [{
          label: 'No of Registrations',
          data: [10, 19, 8, 10],
          backgroundColor: ['#B266FF', '#B266FF', '#B266FF', '#B266FF'],
          borderColor: ['#B266FF', '#B266FF', '#B266FF', '#B266FF'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var msme_feedback_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };



    
    var chartInstances = {};
  
    function initializeChart(chartId, chartType, chartData, chartOptions) {
      var ctx = $(chartId).get(0).getContext("2d");
      return new Chart(ctx, {
        type: chartType,
        data: chartData,
        options: chartOptions
      });
    }
  
    if ($("#msme_cities").length) {
        chartInstances["msme_cities"] = initializeChart("#msme_cities", 'pie', msme_cities_data, msme_cities_options);
    }

    if ($("#msme_category").length) {
        chartInstances["msme_category"] = initializeChart("#msme_category", 'doughnut', msme_category_data, msme_category_options);
    }

    if ($("#msme_feedback").length) {
        chartInstances["msme_feedback"] = initializeChart("#msme_feedback", 'bar', msme_feedback_data, msme_feedback_options);
    }
  



    document.querySelectorAll('.btn-maximize').forEach(button => {
      button.addEventListener('click', function() {
        var card = this.closest('.card');
        var title = card.querySelector('.card-title').innerText;
        var canvas = card.querySelector('canvas');
        var canvasId = canvas.id;
  
        document.getElementById('maximized-card-title').innerText = title;
  
        var maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');
  
        if (window.maximizedChartInstance) {
          window.maximizedChartInstance.destroy();
        }
  
        var originalChart = chartInstances[canvasId];
        var chartConfig = {
          type: originalChart.config.type,
          data: originalChart.config.data,
          options: originalChart.config.options
        };
  
        var maximizedChartCanvas = document.getElementById('maximized-chart').getContext('2d');
        window.maximizedChartInstance = new Chart(maximizedChartCanvas, chartConfig);
      });
    });
  
    document.querySelector('.btn-close').addEventListener('click', function() {
      var maximizedContainer = document.getElementById('maximized-card-container');
      maximizedContainer.classList.add('d-none');
  
      if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
      }
    });
    
  });
  