$(function() {
    /* ChartJS
     * -------
     * Data and config for chartjs
     */
    'use strict';

    var incoming_ivr_data = {
        datasets: [{
          data: [35, 50],
          backgroundColor: ['#FFFF00', '#994C00'],      
          borderColor: ['#FFFF00', '#994C00']
        }],
        labels: ['Registration', 'Calls']      
      };
    
      var incoming_ivr_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };

      var workfair_conducted_data = {
        labels: ["Workfair", "Campus"],
        datasets: [{
          label: '# of Votes',
          data: [4, 17, 0],
          backgroundColor: ['#FF9933', '#FF9933'],
          borderColor: ['#FF9933', '#FF9933'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var workfair_conducted_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };
  
      var reg_vs_app_data = {
        datasets: [{
          data: [20, 40],
          backgroundColor: ['#d233ff', '#90ff33'],
          borderColor: ['#d233ff', '#90ff33']
        }],
        labels: ['Registration', 'Application']
      };
    
      var reg_vs_app_options = {
        responsive: true,
        animation: 
        {
            animateScale: true,
            animateRotate: true
        },
        legend: 
        {
            display: true,
            position: 'right',
            labels: { boxWidth: 20 }
        }
      };


      var by_qualification_data = {
        labels: ["One", "Two", "Three", "Four", "Five"],
        datasets: [{
          label: 'No of Registrations',
          data: [5, 12, 8, 19, 10],
          backgroundColor: ['#FF66B2', '#FF66B2', '#FF66B2', '#FF66B2', '#FF66B2'],
          borderColor: ['#FF66B2', '#FF66B2', '#FF66B2', '#FF66B2', '#FF66B2'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var by_qualification_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };


      var reg_5days_data = {
        labels: ["Day 1", "Day 2", "Day 3", "Day 4", "Day 5"],
        datasets: [{
          label: 'No of Registrations',
          data: [10, 19, 8, 12, 5],
          backgroundColor: ['#999900', '#999900', '#999900', '#999900', '#999900'],
          borderColor: ['#999900', '#999900', '#999900', '#999900', '#999900'],
          borderWidth: 1,
          fill: false
        }]
      };
    
      var reg_5days_options = {
        scales: {
          yAxes: [{
            ticks: { beginAtZero: true }
          }]
        },
        legend: { display: false },
        elements: { point: { radius: 0 } }
      };


      var dec_reasons_data = {
        datasets: [{
          data: [28, 15, 25, 33, 20],
          backgroundColor: ['#CCFF99', '#CC0066', '#0000FF', '#CC6600', '#CC00CC'],      
          borderColor: ['#CCFF99', '#CC0066', '#0000FF', '#CC6600', '#CC00CC']
        }],
        labels: ['One', 'Two', 'Three', 'Four', 'Five']       
      };
    
      var dec_reasons_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };


      var tele_done_data = {
        datasets: [{
          data: [15, 33, 20, 45],
          backgroundColor: ['#FFAD60', '#FF6F61', '#FFD700', '#FFB6C1'],      
          borderColor: ['#FFAD60', '#FF6F61', '#FFD700', '#FFB6C1']
        }],
        labels: ['Workfair', 'Campus', 'IVR', 'Website']      
      };
    
      var tele_done_options = {
        responsive: true,
        animation: 
        {
          animateScale: true,
          animateRotate: true
        },
        legend: 
        {
          display: true,
          position: 'right',
          labels: { boxWidth: 15 },
        }
      };

      
      var reg_20days_data = {
        labels: ["Day 1", "Day 2", "Day 3", "Day 4", "Day 5", "Day 6", "Day 7", "Day 8", "Day 9", "Day 10", "Day 11", "Day 12", "Day 13", "Day 14", "Day 15", "Day 16", "Day 17", "Day 18", "Day 19", "Day 20"],
        datasets: [{
          label: '# registration in last 20 days',
          data: [10, 19, 3, 5, 2, 3, 6, 8, 2, 11, 15, 7, 3, 5, 7, 9, 12, 8, 5, 3],
          backgroundColor: '#CC00CC', 
        borderColor: '#CC00CC', 
        borderWidth: 2, 
        pointBorderColor: '#99004C', 
        pointBackgroundColor: '#FFFF00', 
        fill: false
        }]
      };

      var reg_20days_options = {
        plugins: {
            filler: {
              propagate: true
            }
          }
      };
      



    var chartInstances = {};
  
    function initializeChart(chartId, chartType, chartData, chartOptions) {
      var ctx = $(chartId).get(0).getContext("2d");
      return new Chart(ctx, {
        type: chartType,
        data: chartData,
        options: chartOptions
      });
    }
  
    if ($("#incoming_ivr").length) {
        chartInstances["incoming_ivr"] = initializeChart("#incoming_ivr", 'doughnut', incoming_ivr_data, incoming_ivr_options);
    }
  
    if ($("#workfair_conducted").length) {
      chartInstances["workfair_conducted"] = initializeChart("#workfair_conducted", 'horizontalBar', workfair_conducted_data, workfair_conducted_options);
    }
  
    if ($("#reg_vs_app").length) {
        chartInstances["reg_vs_app"] = initializeChart("#reg_vs_app", 'doughnut', reg_vs_app_data, reg_vs_app_options);
    }

    if ($("#by_qualification").length) {
        chartInstances["by_qualification"] = initializeChart("#by_qualification", 'bar', by_qualification_data, by_qualification_options);
    }

    if ($("#reg_5days").length) {
        chartInstances["reg_5days"] = initializeChart("#reg_5days", 'bar', reg_5days_data, reg_5days_options);
    }

    if ($("#dec_reasons").length) {
        chartInstances["dec_reasons"] = initializeChart("#dec_reasons", 'pie', dec_reasons_data, dec_reasons_options);
    }

    if ($("#tele_done").length) {
        chartInstances["tele_done"] = initializeChart("#tele_done", 'doughnut', tele_done_data, tele_done_options);
    }

    if ($("#reg_20days").length) {
        chartInstances["reg_20days"] = initializeChart("#reg_20days", 'line', reg_20days_data, reg_20days_options);
    }


    document.querySelectorAll('.btn-maximize').forEach(button => {
      button.addEventListener('click', function() {
        var card = this.closest('.card');
        var title = card.querySelector('.card-title').innerText;
        var canvas = card.querySelector('canvas');
        var canvasId = canvas.id;
  
        document.getElementById('maximized-card-title').innerText = title;
  
        var maximizedContainer = document.getElementById('maximized-card-container');
        maximizedContainer.classList.remove('d-none');
  
        if (window.maximizedChartInstance) {
          window.maximizedChartInstance.destroy();
        }
  
        var originalChart = chartInstances[canvasId];
        var chartConfig = {
          type: originalChart.config.type,
          data: originalChart.config.data,
          options: originalChart.config.options
        };
  
        var maximizedChartCanvas = document.getElementById('maximized-chart').getContext('2d');
        window.maximizedChartInstance = new Chart(maximizedChartCanvas, chartConfig);
      });
    });
  
    document.querySelector('.btn-close').addEventListener('click', function() {
      var maximizedContainer = document.getElementById('maximized-card-container');
      maximizedContainer.classList.add('d-none');
  
      if (window.maximizedChartInstance) {
        window.maximizedChartInstance.destroy();
      }
    });
    
  });
  