<?php

require_once '../model/SFActivity.php';
require_once '../database/Db.php';
require_once '../repository/Crud.php';
require_once '../utils/Utils.php';
require_once 'TokenController.php';
require_once 'CommonController.php';

class SFActivityController
{
    // Create Assignment Activity

    public function createActivity($data, $files)
    {
        $db = getDb();
        $response = "";
        
        $crud = new Crud;
        $commonController  =new CommonController();
        $uploadedFileName = $commonController->uploadFiles($files);
        if ($uploadedFileName){

            $uploadedFileName = implode(',',$uploadedFileName);
            $salesFreelancerActivity = new SalesFreelancerActivity();
            $salesFreelancerActivity->set($data);
            $current_date = getCurrentTime();
            // echo $data;

            $insertActivityStatement = $db->prepare("INSERT INTO `sales_freelancers_activity` (`brand_id`, `activity_name`, `location`, `activity_description`, `document`, `activity_status`, `assignment_id`, `start_date`, `end_date`, `start_time`, `end_time`, `created_at`, `updated_at`, `created_by`, `area`, `pincode`)
            VALUES (:brand_id, :activity_name, :location, :activity_description, :document, :activity_status, :assignment_id, :start_date, :end_date, :start_time, :end_time, :created_at, :updated_at, :created_by, :area, :pincode);");
            
            
            $insertActivityStatement->bindValue(':brand_id', $salesFreelancerActivity->getBrandId());
            $insertActivityStatement->bindValue(':activity_name', $salesFreelancerActivity->getActivityName());
            $insertActivityStatement->bindValue(':location', $salesFreelancerActivity->getLocation());
            $insertActivityStatement->bindValue(':activity_description', $salesFreelancerActivity->getActivityDescription());
            $insertActivityStatement->bindValue(':document', $uploadedFileName);
            $insertActivityStatement->bindValue(':activity_status', $salesFreelancerActivity->getActivityStatus());
            $insertActivityStatement->bindValue(':assignment_id', $salesFreelancerActivity->getAssignmentId());
            $insertActivityStatement->bindValue(':start_date', $salesFreelancerActivity->getStartDate());
            $insertActivityStatement->bindValue(':end_date', $salesFreelancerActivity->getEndDate());
            $insertActivityStatement->bindValue(':start_time', $salesFreelancerActivity->getStartTime());
            $insertActivityStatement->bindValue(':end_time', $salesFreelancerActivity->getEndTime());
            $insertActivityStatement->bindValue(':created_at', $current_date);
            $insertActivityStatement->bindValue(':updated_at', $current_date);
            $insertActivityStatement->bindValue(':created_by', $salesFreelancerActivity->getCreatedBy());
            $insertActivityStatement->bindValue(':area', $salesFreelancerActivity->getArea());
            $insertActivityStatement->bindValue(':pincode', $salesFreelancerActivity->getPincode());

            $result = $crud->create($insertActivityStatement, $db);

            $resultData = json_decode($result, true);
            if ($resultData['result'] == 'success') {
                $response = sendJsonResponseWithParameter(SUCCESS, "Activity Created Successfully", $resultData['id'], 201);
            } else {
                $response = sendJsonResponse(FAILURE, "Failed to Create Activity: " . $resultData['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "Failed to Upload Document ", 400);
        }    
        closeDb($db);
        $db = null;
        return $response;

    } 

    function getActivityListAdmin($data)
    {
        $db = getDb();
        $crud = new Crud();
        $response = "";
        $assignment_id = $data['assignment_id'];
        $stmt = $db->prepare("SELECT id, activity_name FROM `sales_freelancers_activity` WHERE assignment_id = :assignment_id ");
        $stmt->bindValue(':assignment_id', $assignment_id);
        $activityList = $crud->getAllWithoutJSON($stmt);
        if ($activityList) {
            $response = sendDataWithListResponse(SUCCESS, "Activity List", $activityList, 200);
        } else {
            $response = sendDataWithListResponse(FAILURE, "No Activity Found", $activityList, 404);
        }

        closeDb();
        $db = null;
        return $response;

    }

}



class SFActivityController_UandS {

    public function checkUser($data)
    {
        $db = getDb();
        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $assignment_id = $data['assignment_id'];


        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);
        if ($token_found === 1) {
            $crud = new Crud();            
            $activitystmt = $db->prepare("SELECT 
                    activity.activity_name, 
                    activity.activity_location, 
                    activity.activity_address, 
                    activity.activity_description,
                    activity.document,
                    activity.activity_status, 
                    activity.id AS activity_id, 
                    activity.start_date, 
                    activity.end_date, 
                    activity.start_time, 
                    activity.end_time, 
                    COUNT(task.sf_activity_id) AS total_tasks_for_activity 
                FROM 
                    sales_freelancers_activity activity 
                LEFT JOIN 
                    task_for_sf_assignments task ON task.sf_activity_id = activity.id 
                WHERE 
                    activity.assignment_id = $assignment_id 
                GROUP BY 
                    activity.activity_name, 
                    activity.activity_location, 
                    activity.activity_address, 
                    activity.activity_description,
                    activity.document,
                    activity.activity_status, 
                    activity.id, 
                    activity.start_date, 
                    activity.end_date, 
                    activity.start_time, 
                    activity.end_time;
                ");

            $result = $crud->getAll($activitystmt);
            closeDb();
            $db = null;
            return $result;

        }


    }
    

}