<?php

require_once '../model/SFActivityStatus.php';
require_once '../database/Db.php'; 
require_once '../repository/Crud.php'; 
require_once '../utils/Utils.php'; 
require_once 'TokenController.php';

class SFActivityStatusController
{
    public function createActivityStatus($data)
    {
        $db = getDb();
        $response = "";
        $token = $data['session_token'];
        $user_id = $data['user_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            $activityStatus = new SFActivityStatus();
            $activityStatus->set($data);

            $crud = new Crud();

            $insertActivityStatusStatement = $db->prepare("INSERT INTO `sales_freelancers_activity_status` (`activity_id`, `activity_status`, `photos`, `videos`, `comment`, `notes`, `check_in_latitude`, `check_in_longitude`, `check_out_latitude`, `check_out_longitude`, `check_selfie`, `users_id`, `assignment_id`, `created_at`, `updated_at`, `created_by`)
            VALUES (:activity_id, :activity_status, :photos, :videos, :comment, :notes, :check_in_latitude, :check_in_longitude, :check_out_latitude, :check_out_longitude, :check_selfie, :users_id, :assignment_id, :created_at, :updated_at, :created_by)");

            $insertActivityStatusStatement->bindValue(':activity_id', $activityStatus->getActivityId());
            $insertActivityStatusStatement->bindValue(':activity_status', $activityStatus->getActivityStatus());
            $insertActivityStatusStatement->bindValue(':photos', $activityStatus->getPhotos());
            $insertActivityStatusStatement->bindValue(':videos', $activityStatus->getVideos());
            $insertActivityStatusStatement->bindValue(':comment', $activityStatus->getComment());
            $insertActivityStatusStatement->bindValue(':notes', $activityStatus->getNotes());
            $insertActivityStatusStatement->bindValue(':check_in_latitude', $activityStatus->getCheckInLatitude());
            $insertActivityStatusStatement->bindValue(':check_in_longitude', $activityStatus->getCheckInLongitude());
            $insertActivityStatusStatement->bindValue(':check_out_latitude', $activityStatus->getCheckOutLatitude());
            $insertActivityStatusStatement->bindValue(':check_out_longitude', $activityStatus->getCheckOutLongitude());
            $insertActivityStatusStatement->bindValue(':check_selfie', $activityStatus->getCheckSelfie());
            $insertActivityStatusStatement->bindValue(':users_id', $activityStatus->getUserId());
            $insertActivityStatusStatement->bindValue(':assignment_id', $activityStatus->getAssignmentId());
            $insertActivityStatusStatement->bindValue(':created_at', $current_date);
            $insertActivityStatusStatement->bindValue(':updated_at', $current_date);
            $insertActivityStatusStatement->bindValue(':created_by', $user_id);

            $result = $crud->create($insertActivityStatusStatement, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $res['id'], 201);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }


    // Update Photos
    public function updatePhotos($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $activity_id = $data['activity_id'];
        $current_date = getCurrentTime();

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $updatePhotos = $db->prepare("UPDATE sales_freelancers_activity_status SET photos = :photos, updated_at = :updated_at
            WHERE activity_id = :activity_id AND created_by = :created_by");

            $updatePhotos->bindValue(':photos', $data['photos']);
            $updatePhotos->bindValue(':updated_at', $current_date);
            $updatePhotos->bindValue(':activity_id', $activity_id);
            $updatePhotos->bindValue(':created_by', $user_id);

            $result = $crud->update($updatePhotos, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $activity_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }


    // Update Videos
    public function updateVideos($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $activity_id = $data['activity_id'];
        $current_date = getCurrentTime();

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $updateVideos = $db->prepare("UPDATE sales_freelancers_activity_status SET videos = :videos, updated_at = :updated_at
            WHERE activity_id = :activity_id AND created_by = :created_by");

            $updateVideos->bindValue(':videos', $data['videos']);
            $updateVideos->bindValue(':updated_at', $current_date);
            $updateVideos->bindValue(':activity_id', $activity_id);
            $updateVideos->bindValue(':created_by', $user_id);

            $result = $crud->update($updateVideos, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $activity_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

    
    // Update Status
    public function updateStatus($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $activity_id = $data['activity_id'];
        $current_date = getCurrentTime();

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $updateStatus = $db->prepare("UPDATE sales_freelancers_activity_status SET activity_status = :activity_status, updated_at = :updated_at
            WHERE activity_id = :activity_id AND created_by = :created_by");

            $updateStatus->bindValue(':activity_status', $data['activity_status']);
            $updateStatus->bindValue(':updated_at', $current_date);
            $updateStatus->bindValue(':activity_id', $activity_id);
            $updateStatus->bindValue(':created_by', $user_id);

            $result = $crud->update($updateStatus, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $activity_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }


    // Update Comment and Notes
    public function updateCommentNotes($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $activity_id = $data['activity_id'];
        $current_date = getCurrentTime();

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $updateCommentNotes = $db->prepare("UPDATE sales_freelancers_activity_status SET comment = :comment, notes = :notes, updated_at = :updated_at
            WHERE activity_id = :activity_id AND created_by = :created_by");

            $updateCommentNotes->bindValue(':comment', $data['comment']);
            $updateCommentNotes->bindValue(':notes', $data['notes']);
            $updateCommentNotes->bindValue(':updated_at', $current_date);
            $updateCommentNotes->bindValue(':activity_id', $activity_id);
            $updateCommentNotes->bindValue(':created_by', $user_id);

            $result = $crud->update($updateCommentNotes, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $activity_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

}
