<?php

require_once '../model/SFLeads.php';
require_once '../database/Db.php'; 
require_once '../repository/Crud.php'; 
require_once '../utils/Utils.php'; 
require_once 'TokenController.php';

class SFLeadsController
{
    
    // Create Leads
    public function createLeads($data)
    {
        $db = getDb();
        $response = "";
        $token = $data['session_token'];
        $user_id = $data['user_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            // $leadData = $data; 
            $lead = new SFLeads();
            $lead->set($data);

            $crud = new Crud();

            // Check if the lead already exists (Contact Number & Email)
            $checkLeadStatement = $db->prepare("SELECT COUNT(*) FROM `sales_freelancer_leads` WHERE `contact_number` = :contact_number OR `contact_email` = :contact_email");
            $checkLeadStatement->bindValue(':contact_number', $lead->getContactNumber());
            $checkLeadStatement->bindValue(':contact_email', $lead->getContactEmail());
            $checkLeadResult = $crud->getCount($checkLeadStatement);

            if ($checkLeadResult == 0) {
                $insertLeadStatement = $db->prepare("INSERT INTO sales_freelancer_leads (name, lead_type, contact_number, contact_email, contact_address, city, state, pincode, notes, created_at, updated_at, created_by, latitude, longitude, company_name, source_from, designation, location_details, assigned_to, assigned_by, status, lead_status, last_contacted_by, last_action, feedback)
                VALUES (:name, :lead_type, :contact_number, :contact_email, :contact_address, :city, :state, :pincode, :notes, :created_at, :updated_at, :created_by, :latitude, :longitude, :company_name, :source_from, :designation, :location_details, :assigned_to, :assigned_by, :status, :lead_status, :last_contacted_by, :last_action, :feedback)");

                $insertLeadStatement->bindValue(':name', $lead->getName());
                $insertLeadStatement->bindValue(':lead_type', $lead->getLeadType());
                $insertLeadStatement->bindValue(':contact_number', $lead->getContactNumber());
                $insertLeadStatement->bindValue(':contact_email', $lead->getContactEmail());
                $insertLeadStatement->bindValue(':contact_address', $lead->getContactAddress());
                $insertLeadStatement->bindValue(':city', $lead->getCity());
                $insertLeadStatement->bindValue(':state', $lead->getState());
                $insertLeadStatement->bindValue(':pincode', $lead->getPincode());
                $insertLeadStatement->bindValue(':notes', $lead->getNotes());
                $insertLeadStatement->bindValue(':created_at', $current_date);
                $insertLeadStatement->bindValue(':updated_at', $current_date);
                $insertLeadStatement->bindValue(':created_by', $user_id);
                $insertLeadStatement->bindValue(':latitude', $lead->getLatitude());
                $insertLeadStatement->bindValue(':longitude', $lead->getLongitude());
                $insertLeadStatement->bindValue(':company_name', $lead->getCompanyName());
                $insertLeadStatement->bindValue(':source_from', $lead->getSourceFrom());
                $insertLeadStatement->bindValue(':designation', $lead->getDesignation());
                $insertLeadStatement->bindValue(':location_details', $lead->getLocationDetails());
                $insertLeadStatement->bindValue(':assigned_to', $lead->getAssignedTo());
                $insertLeadStatement->bindValue(':assigned_by', $lead->getAssignedBy());
                $insertLeadStatement->bindValue(':status', $lead->getStatus());
                $insertLeadStatement->bindValue(':lead_status', $lead->getLeadStatus());
                $insertLeadStatement->bindValue(':last_contacted_by', $user_id);
                $insertLeadStatement->bindValue(':last_action', $lead->getLastAction());
                $insertLeadStatement->bindValue(':feedback', $lead->getFeedback());

                $result = $crud->create($insertLeadStatement, $db);
                $res = json_decode($result, true);

                if ($res['result'] == 'success') {
                    $response = sendJsonResponseWithParameter($res['result'], $res['message'], $res['id'], 201);
                } else {
                    $response = sendJsonResponse($res['result'], $res['message'], 400);
                }
            } else {
                $response = sendJsonResponse(FAILURE, "Lead Already Exists", 409);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }


    // Get Leads
    public function getLeads($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $getLeads = $db->prepare("SELECT * FROM sales_freelancer_leads WHERE created_by = :created_by");
            $getLeads->bindValue(':created_by', $user_id);

            $leadsList = $crud->getAllWithoutJSON($getLeads);

            if (!is_null($leadsList) && count($leadsList) > 0) {
                $response = sendDataWithListResponse(SUCCESS, "Leads Can Be Found.", $leadsList, 200);
            } else {
                $response = sendJsonResponse(FAILURE, "Leads Cannot Be Found.", 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }


    // Update Leads
    public function updateLeads($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $lead_id = $data['lead_id'];
        $current_date = getCurrentTime();

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $updateLead = $db->prepare("UPDATE sales_freelancer_leads SET name = :name, lead_type = :lead_type, contact_number = :contact_number, contact_email = :contact_email, contact_address = :contact_address, city = :city, state = :state, pincode = :pincode, notes = :notes, updated_at = :updated_at, latitude = :latitude, longitude = :longitude, company_name = :company_name, location_details = :location_details, assigned_to = :assigned_to, status = :status, last_action = :last_action, feedback = :feedback
            WHERE id = :lead_id AND created_by = :created_by");

            $updateLead->bindValue(':name', $data['name']);
            $updateLead->bindValue(':lead_type', $data['lead_type']);
            $updateLead->bindValue(':contact_number', $data['contact_number']);
            $updateLead->bindValue(':contact_email', $data['contact_email']);
            $updateLead->bindValue(':contact_address', $data['contact_address']);
            $updateLead->bindValue(':city', $data['city']);
            $updateLead->bindValue(':state', $data['state']);
            $updateLead->bindValue(':pincode', $data['pincode']);
            $updateLead->bindValue(':notes', $data['notes']);
            $updateLead->bindValue(':updated_at', $current_date);
            $updateLead->bindValue(':latitude', $data['latitude']);
            $updateLead->bindValue(':longitude', $data['longitude']);
            $updateLead->bindValue(':company_name', $data['company_name']);
            $updateLead->bindValue(':location_details', $data['location_details']);
            $updateLead->bindValue(':assigned_to', $data['assigned_to']);
            $updateLead->bindValue(':status', $data['status']);
            $updateLead->bindValue(':lead_id', $lead_id);
            $updateLead->bindValue(':created_by', $user_id);
            $updateLead->bindValue(':last_action', $data['last_action']);
            $updateLead->bindValue(':feedback', $data['feedback']);

            $result = $crud->update($updateLead, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $lead_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }
}
