<?php

require_once '../model/SFTask.php';
require_once '../database/Db.php'; 
require_once '../repository/Crud.php'; 
require_once '../utils/Utils.php'; 
require_once 'TokenController.php';

class TaskForSFController
{
    // For Admin
    // Create Task
    public function createTask($data)
    {
        $db = getDb();
        $response = "";
            $salesFreelancerTask = new TaskForSF();
            $salesFreelancerTask->set($data);
            $current_date = getCurrentTime();

            $insertTaskStatement = $db->prepare("INSERT INTO `task_for_sf_assignments` (`brand_id`, `sf_assignment_id`, `sf_activity_id`, `task_name`, `start_date`, `end_date`, `task_status`, `task_description`, `created_at`, `updated_at`)
            VALUES (:brand_id, :sf_assignment_id, :sf_activity_id, :task_name, :start_date, :end_date, :task_status, :task_description, :created_at, :updated_at);");

            $insertTaskStatement->bindValue(':brand_id', $salesFreelancerTask->getBrandId());   
            $insertTaskStatement->bindValue(':sf_assignment_id', $salesFreelancerTask->getAssignmentId());
            $insertTaskStatement->bindValue(':sf_activity_id', $salesFreelancerTask->getActivityId());
            $insertTaskStatement->bindValue(':task_name', $salesFreelancerTask->getTaskName());
            $insertTaskStatement->bindValue(':start_date', $salesFreelancerTask->getStartDate());
            $insertTaskStatement->bindValue(':end_date', $salesFreelancerTask->getEndDate());
            $insertTaskStatement->bindValue(':task_status', $salesFreelancerTask->getTaskStatus());
            $insertTaskStatement->bindValue(':task_description', $salesFreelancerTask->getTaskDescription());
            $insertTaskStatement->bindValue(':created_at', $current_date);
            $insertTaskStatement->bindValue(':updated_at', $current_date);
            
            $crud = new Crud;
            $result = $crud->create($insertTaskStatement, $db);

            $resultData = json_decode($result, true);
            if ($resultData['result'] == 'success') {
                $response = sendJsonResponseWithParameter(SUCCESS, "Task Created Successfully", $resultData['id'], 201);
            } else {
                $response = sendJsonResponse(FAILURE, "Failed to Create Task: " . $resultData['message'], 400);
            }
            
        closeDb($db);
        $db = null;
        return $response;

    } 


    // For App
    // Add Task
    public function addTask($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $assignment_id = $data['sf_assignment_id'];

        // Verify Token
        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            $task = new TaskForSF();
            $task->set($data);

            $crud = new Crud();

            // Insert Task
            $insertTask = $db->prepare("INSERT INTO `task_for_sf_assignments` (`task_name`, `task_completion_date`, `task_status`, `check_in`, `check_out`, `task_details`, `proof_image_1`, `proof_image_2`, `photos`, `videos`, `created_at`, `updated_at`, `sf_assignment_id`, `created_by`, `task_document`, `location`)
            VALUES (:task_name, :task_completion_date, :task_status, :check_in, :check_out, :task_details, :proof_image_1, :proof_image_2, :photos, :videos, :created_at, :updated_at, :sf_assignment_id, :created_by, :task_document, :location)");
            
            $insertTask->bindValue(':task_name', $task->getTaskName());
            $insertTask->bindValue(':task_completion_date', $task->getTaskCompletionDate());
            $insertTask->bindValue(':task_status', $task->getTaskStatus());
            $insertTask->bindValue(':check_in', $current_date);
            $insertTask->bindValue(':check_out', $current_date);
            $insertTask->bindValue(':task_details', $task->getTaskDetails());
            $insertTask->bindValue(':proof_image_1', $task->getProofImage1());
            $insertTask->bindValue(':proof_image_2', $task->getProofImage2());
            $insertTask->bindValue(':photos', $task->getPhotos());
            $insertTask->bindValue(':videos', $task->getVideos());
            $insertTask->bindValue(':created_at', $current_date);
            $insertTask->bindValue(':updated_at', $current_date);
            $insertTask->bindValue(':sf_assignment_id', $assignment_id);
            $insertTask->bindValue(':created_by', $user_id);
            $insertTask->bindValue(':task_document', $task->getTaskDocument());
            $insertTask->bindValue(':location', $task->getLocation());

            $result = $crud->create($insertTask, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $res['id'], 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token could not be found...", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

    // Get Task
    public function getTask($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $assignment_id = $data['sf_assignment_id'];
        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $crud = new Crud();
            $getTask = $db->prepare("SELECT * FROM task_for_sf_assignments WHERE sf_assignment_id = :sf_assignment_id AND created_by = :created_by");
            $getTask->bindValue(':sf_assignment_id', $assignment_id);
            $getTask->bindValue(':created_by', $user_id);

            $taskList = $crud->getAllWithoutJSON($getTask);

            if (!is_null($taskList) && count($taskList) > 0) {
                $response = sendDataWithListResponse(SUCCESS, "Tasks found", $taskList, 200);
            } else {
                $response = sendJsonResponse(FAILURE, "No tasks found", 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token could not be found...", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

    // Update Task
    public function updateTask($data)
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $assignment_id = $data['sf_assignment_id'];
        $task_id = $data['task_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            $crud = new Crud();
            $updateTask = $db->prepare("UPDATE task_for_sf_assignments SET task_name = :task_name, task_completion_date = :task_completion_date, task_status = :task_status, task_details = :task_details, proof_image_1 = :proof_image_1, proof_image_2 = :proof_image_2, updated_at = :updated_at, task_document = :task_document, location = :location
            WHERE id = :task_id AND sf_assignment_id = :sf_assignment_id AND created_by = :created_by");

            $updateTask->bindValue(':task_name', $data['task_name']);
            $updateTask->bindValue(':task_completion_date', $data['task_completion_date']);
            $updateTask->bindValue(':task_status', $data['task_status']);
            $updateTask->bindValue(':task_details', $data['task_details']);
            $updateTask->bindValue(':proof_image_1', $data['proof_image_1']);
            $updateTask->bindValue(':proof_image_2', $data['proof_image_2']);
            $updateTask->bindValue(':updated_at', $current_date);
            $updateTask->bindValue(':task_document', $data['task_document']);
            $updateTask->bindValue(':location', $data['location']);
            $updateTask->bindValue(':task_id', $task_id);
            $updateTask->bindValue(':sf_assignment_id', $assignment_id);
            $updateTask->bindValue(':created_by', $user_id);

            $result = $crud->update($updateTask, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $task_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        } else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found...", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

    // Update Photos
    public function updatePhotos($data) 
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $task_id = $data['task_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            $crud = new Crud();
            $updatePhotos = $db->prepare("UPDATE task_for_sf_assignments SET photos = :photos, updated_at = :updated_at
            WHERE id = :task_id AND created_by = :created_by");

            $updatePhotos->bindValue(':photos', $data['photos']);
            $updatePhotos->bindValue(':updated_at', $current_date);
            $updatePhotos->bindValue(':task_id', $task_id);
            $updatePhotos->bindValue(':created_by', $user_id);

            $result = $crud->update($updatePhotos, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $task_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        }
        else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.....", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }

    // Update Videos
    public function updateVideos($data) 
    {
        $db = getDb();
        $response = "";

        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $task_id = $data['task_id'];

        $tokenController = new TokenController();
        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {
            $current_date = getCurrentTime();
            $crud = new Crud();
            $updateVideos = $db->prepare("UPDATE task_for_sf_assignments SET videos = :videos, updated_at = :updated_at
            WHERE id = :task_id AND created_by = :created_by");

            $updateVideos->bindValue(':videos', $data['videos']);
            $updateVideos->bindValue(':updated_at', $current_date);
            $updateVideos->bindValue(':task_id', $task_id);
            $updateVideos->bindValue(':created_by', $user_id);

            $result = $crud->update($updateVideos, $db);
            $res = json_decode($result, true);

            if ($res['result'] == 'success') {
                $response = sendJsonResponseWithParameter($res['result'], $res['message'], $task_id, 200);
            } else {
                $response = sendJsonResponse($res['result'], $res['message'], 400);
            }
        }
        else {
            $response = sendJsonResponse(FAILURE, "The Token Could Not Be Found.....", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }
    
}
