<?php

require_once '../model/UserAssignments.php';
require_once '../database/Db.php'; 
require_once '../repository/Crud.php'; 
require_once '../utils/Utils.php'; 
include_once '../utils/SuperApp.php';


class UserAssignmentsController {

    public function createUserAssignments($data)
    {
        $db = getDb();
        $userAssignments = new UserAssignments();
        $userAssignments->set($data);
        $current_date = getCurrentTime();
        $crud = new Crud;
        $response = "";
        $successCount = 0;
        $failureCount = 0;
        $errorDetails = [];

        foreach ($data['user_id'] as $userId) {
            // Prepare the insert statement for each user ID
            $insertUserAssignment = $db->prepare("INSERT INTO `assign_assignments_to_users` (`brand_id`, `assignment_id`, `activity_id`, `created_at`, `updated_at`, `user_id`)
            VALUES (:brand_id, :assignment_id, :activity_id, :created_at, :updated_at, :user_id)");

            $insertUserAssignment->bindValue(':brand_id', $data['brand_id']);
            $insertUserAssignment->bindValue(':assignment_id', $data['assignment_id']);
            $insertUserAssignment->bindValue(':activity_id', $data['activity_id']);
            $insertUserAssignment->bindValue(':created_at', $current_date);
            $insertUserAssignment->bindValue(':updated_at', $current_date);
            $insertUserAssignment->bindValue(':user_id', $userId);

            // Execute the insert operation
            $result = $crud->create($insertUserAssignment, $db);
            $resultData = json_decode($result, true);

            if ($resultData['result'] == 'success') {
                $successCount++;
            } else {
                $failureCount++;
                $errorDetails[] = "Failed to assign to User ID: $userId";
            }
        }

        if ($failureCount > 0) {
            $response = sendJsonResponse(FAILURE, "Failed to assign some users", 400, [
                'success_count' => $successCount,
                'failure_count' => $failureCount,
                'errors' => $errorDetails
            ]);
        } else {
            $response = sendDataWithListResponse(SUCCESS, "Assignment to Users Created Successfully", [
                'success_count' => $successCount,
                'failure_count' => $failureCount
            ], 201);
        }

        closeDb($db);
        return $response;
    }
        

        

    public function getUserListAdmin(){

        $db = getDb();
        $crud = new Crud();
        $response = [];
        $stmt = $db->prepare("SELECT id, first_name, last_name, mobile_number FROM `users_v2` ");
        $rowUser = $crud->getAllWithoutJSON($stmt);
        // print_r($rowUser);
        $decryptData = $this->decryptUserList($rowUser);
        if (count($decryptData) > 0){
            $response = sendDataWithListResponse(SUCCESS, "User List", $decryptData, 200);
        }else {
            $response = sendJsonResponse(FAILURE, "No User Found",404);
        }
        return $response;            
    }

    private function decryptUserList($rowUser){
        $users_array = [];
        foreach($rowUser as $row){
            $obj = new stdClass();

            $obj->name = $this->decrypt($row['first_name']) . ' ' . $this->decrypt($row['last_name']);
            $obj->mobile_number = $this->decrypt($row['mobile_number']);
            $obj->id = $row['id'];
            // var_dump($obj);


            $users_array[] = $obj;
        }    
        return $users_array;   
    }
    
    private function decrypt($data)
    {
        //todo: put this in .env file....
        $decrypted_key = base64_decode(ENCRYPTION_KEY);
        $decrypted_iv = base64_decode(ENCRYPTION_IV);
        return openssl_decrypt($data, CIPHER, $decrypted_key, OPENSSL_RAW_DATA, $decrypted_iv);
    }
}
