<?php

require_once '../model/LeadSalesforce.php'; 
require_once '../database/Db.php'; 
require_once '../repository/Crud.php'; 
require_once '../utils/Utils.php'; 

class LeadsController
{
    public function addLeadSalesforce($data)
    {
        $db = getDb(); 
        $response = "";

        try {
            $leadData = $data['lead_salesforce'];
            $leadSalesforce = new LeadSalesforce();
            $leadSalesforce->set($leadData); 
            $current_date = getCurrentTime();

            // Insert query for Leads Salesforce Table
            $insertLeadStatement = $db->prepare("INSERT INTO `leads_salesforce`(`company_name`, `company_type`, `contact_number`, `contact_email`, `contact_address`, `pincode`, `notes`, `latitude`, `longitude`, `created_by`, `created_at`, `updated_at`)
            VALUES (:company_name, :company_type, :contact_number, :contact_email, :contact_address, :pincode, :notes, :latitude, :longitude, :created_by, :created_at, :updated_at)");

            $insertLeadStatement->bindValue(':company_name', $leadSalesforce->getCompanyName());
            $insertLeadStatement->bindValue(':company_type', $leadSalesforce->getCompanyType());
            $insertLeadStatement->bindValue(':contact_number', $leadSalesforce->getContactNumber());
            $insertLeadStatement->bindValue(':contact_email', $leadSalesforce->getContactEmail());
            $insertLeadStatement->bindValue(':contact_address', $leadSalesforce->getContactAddress());
            $insertLeadStatement->bindValue(':pincode', $leadSalesforce->getPincode());
            $insertLeadStatement->bindValue(':notes', $leadSalesforce->getNotes());
            $insertLeadStatement->bindValue(':latitude', $leadSalesforce->getLatitude());
            $insertLeadStatement->bindValue(':longitude', $leadSalesforce->getLongitude());
            $insertLeadStatement->bindValue(':created_by', $leadSalesforce->getCreatedBy());
            $insertLeadStatement->bindValue(':created_at', $current_date);
            $insertLeadStatement->bindValue(':updated_at', $current_date);

            $crud = new Crud();
            $result = $crud->create($insertLeadStatement, $db);

            $resultData = json_decode($result, true);
            if ($resultData['result'] == 'success') {
                $response = sendJsonResponseWithParameter(true, "Lead created successfully", $resultData['id'], 201);
            } else {
                $response = sendJsonResponse(false, "Failed to create lead: " . $resultData['message'], 400);
            }

        } catch (PDOException $e) {
            $response = sendJsonResponse(false, "Error: " . $e->getMessage(), 500);
        }

        closeDb($db); 

        return $response;
    }
}
