<?php
require_once '../model/User.php';
require_once '../utils/Utils.php';
require_once '../repository/Crud.php';
require_once '../database/Db.php';
require_once '../utils/SuperApp.php';
require_once '../utils/SendEmail.php';



class SignUpController
{


    public function createSuperAppUser($data)
    {

        /** check if the user input is correct */

        if (!$this->checkValidData($data)) {
              if (!isValidEmail($data['email_id'])) {
                $result = "Failure";
                $message = "Invalid Email format";
                $response =  sendJsonResponse($result, $message, 400);
            } else if (!isValidMobileNumber($data['mobile_number'])) {
                $result = "Failure";
                $message = "Invalid Phone Number it must 10 digits only numbers";
                $response = sendJsonResponse($result, $message, 400);
            } else if (!isValidPincode($data['pincode'])) {
                $result = "Failure";
                $message = "Invalid Pincode it must be 6 digits with only digits";
                $response = sendJsonResponse($result, $message, 400);
            }
            return $response;
        } else if ($this->checkValidData($data)) {


            /** use same encryption and check the user is already taken */

            // get DB connection
            $db = getDb();
            $date = getCurrentTime();
            // unique identifier for the user..
            $user_id = uniqid();
            // initialize crud for database operations...
            $crud = new Crud();
            // initialize json obj
            $user = new User();
            $user->setEmailId($data['email_id']);
            $user->setFirstName($data['first_name']);
            $user->setLastName($data['last_name']);
            $user->setMobileNumber($data['mobile_number']);
            $user->setPassword($autopassword);
            $user->setAddress($data['address']);
            $user->setCity($data['city']);
            $user->setState($data['state']);
            $user->setQualification($data['qualification']);

            $user->setPincode($data['pincode']);



            // Encrypt the username to check
            $encrypted_username_indb = $user->getEncryptedMobileNumber();

            $find_user = $db->prepare("SELECT * FROM `users_v2`  WHERE username =:username");
            $find_user->bindValue(':username', $encrypted_username_indb);

            $user_found = $crud->findUserWithoutJson($find_user);

            if ($user_found == 0) {
                // set the data to the user model...
                // check if user already exists...
                // Encrypt the PII data and Save to database
                $encrypted_mobile = $user->getEncryptedMobileNumber();  // encrypted
                $encrypted_email = $user->getEncryptedEmailId();        // encrypted
                $encrypted_first_name = $user->getEncryptedFirstName(); // encrypted
                $encrypted_last_name = $user->getEncryptedLastName();   // encrypted
                $encrypted_password = $user->getEncryptedPassword(); // encrypted

                // start the insert process of users_v2

                try {
                    $db->beginTransaction();
                    $stmt = $db->prepare("INSERT INTO `users_v2`(`user_id`, `first_name`, `last_name`, `username`, `password`, `mobile_number`, `email_id`, `address`, `city`, `state`, `pincode`, `created_at`, `updated_at`,`user_type`) 
                                                    VALUES (:user_id,:first_name,:last_name,:username,:password,:mobile_number,:email_id,:address,:city,:state,:pincode, :created_at, :updated_at, :user_type)");
                    $stmt->bindValue(':user_id', $user_id);
                    $stmt->bindValue(':first_name', $encrypted_first_name);
                    $stmt->bindValue(':last_name', $encrypted_last_name);
                    $stmt->bindValue(':username', $encrypted_mobile);
                    $stmt->bindValue(':password', $encrypted_password);
                    $stmt->bindValue(':mobile_number', $encrypted_mobile);
                    $stmt->bindValue(':email_id', $encrypted_email);
                    $stmt->bindValue(':address', $user->getAddress());
                    $stmt->bindValue(':city', $user->getCity());
                    $stmt->bindValue(':state', $user->getState());
                    $stmt->bindValue(':pincode', $user->getPincode());
                    $stmt->bindValue(':created_at', $date);
                    $stmt->bindValue(':updated_at', $date);
                    $stmt->bindValue(':user_type', "SuperAppUser");


                    if ($stmt->execute()) {
                        $insertuserStmt = $db->prepare("INSERT INTO `super_app_users`(`user_id`, `status`, `orientation`, `created_at`, `updated_at`)
                                                                  VALUES (:user_id,:status,:orientation,:created_at,:updated_at)");

                        $insertuserStmt->bindValue(':user_id', $user_id);
                        $insertuserStmt->bindValue(':status', 'Active'); // default status is active
                        $insertuserStmt->bindValue(':orientation', 0);
                        $insertuserStmt->bindValue(':created_at', $date);
                        $insertuserStmt->bindValue(':updated_at', $date);


                        if ($insertuserStmt->execute()) {
                            $db->commit();
                            $result = "success";
                            $message = "User Registered Successfully";
                            $response = sendJsonResponseWithParameter($result, $message, $user_id, 201);
                            
                            $mail_send =  getCatalystRegistrationContent($data['first_name'], $data['mobile_number'], $autopassword, "technology@jeevitam.com", $data['email_id']);
                            if ($mail_send === 'success') {
                                $crud = new Crud();
                                $stmt = $db->prepare("UPDATE users_v2 set welcome_email_sent=1 WHERE user_id = '$user_id'");
                                $result_update = $crud->update($stmt);
                            }
                        } else {
                            $db->rollBack();
                            $message = json_encode($insertuserStmt->errorInfo());
                            $result = "failure";
                            $response =  sendJsonResponse($result, $message, 400);
                        }
                    } else {
                        $db->rollBack();
                        $message = json_encode($stmt->errorInfo());
                        $result = "failure";
                        $response = sendJsonResponse($result, $message, 400);
                    }
                } catch (PDOException $ex) {
                    $db->rollBack();
                    $result = "failure";
                    $message = $ex->getMessage();
                    $response = sendJsonResponse($result, $message, 400);
                }

                closeDb();
                $db = null;
                return $response;
            } else if ($user_found == 1) {

                $result = "failure";
                $message = "The provided username" . $data['mobile_number'] . " is already taken";
                $response = sendJsonResponse($result, $message, 400);
                return $response;
            } else if ($user_found == -1) {

                $result = "failure";
                $message = "Invalid details";
                $response = sendJsonResponse($result, $message, 400);
                return $response;

                // throw invalid user
            }
        }
    }

    private function checkValidData($data)
    {

        if (
            isValidMobileNumber($data['mobile_number']) &&
            isValidPincode($data['pincode'])
            && isValidEmail($data['email_id'])
        ) {
            return true;
        } else {
            return false;
        }
    }
}
