<?php

require_once '../model/User.php';
require_once '../model/DecryptedData.php';
require_once '../model/Token.php';
require_once '../model/AuthenticateUser.php';
require_once '../utils/Utils.php';
require_once '../repository/Crud.php';
require_once '../database/Db.php';
require_once '../utils/SuperApp.php';
require_once 'TokenController.php';


class UserController
{


    public function authenticateUser($data)
    {


        $authenticateUser = new AuthenticateUser();
        $authenticateUser->set($data);

        $username = $authenticateUser->getUsername();
        $user_password = $authenticateUser->getUserPassword();
        $device_id = $authenticateUser->getDeviceId();
        $device_name = $authenticateUser->getDeviceName();
        $device_token = $authenticateUser->getDeviceToken();


        $response = "";


        // encrypt the given username
        $user = new User();
        $user->setUserName($username);
        $user->setPassword($user_password);
        $encrypted_username = $user->getEncryptedUserName();
        $encrypted_password = $user->getEncryptedPassword();
        


        $db = getDb();
        $crud = new Crud();

        $find_user = $db->prepare("SELECT * FROM `users_v2`  WHERE username =:username");
        $find_user->bindValue(':username', $encrypted_username);

        $user_found = $crud->findUserWithoutJson($find_user);

        if ($user_found == 1) {

            $stmt1 = $db->prepare("SELECT password FROM `users_v2` where password =:password");
            $stmt1->bindValue(':password', $encrypted_password);

            $db_password = $crud->findPassword($stmt1);

            if (!is_null($db_password) && !empty($db_password)) {
                /** dcrypt which is present from db... */

                $decrypted_password = $this->decrypt($db_password);

                if ($decrypted_password === $user_password) {
                    


                    $stmt2 = $db->prepare("SELECT * FROM `users_v2` where username=:username");
                    $stmt2->bindValue(':username', $encrypted_username);
                    
                    // get the complete user details from db and create a token...

                    $rowUser = $crud->getByCondition($stmt2);
                    $decryptData = $this->decryptUser($rowUser);
                    
                    $token = new Token();
                    $token->setDeviceId($device_id);
                    $token->setDeviceName($device_name);
                    $token->setUserId($rowUser['id']);
                    $token->setToken($device_token); // save this in the user table later

                    //todo :during login always delete previous sessions...only if the user has sessions */
                    

                    $tokenController = new TokenController();
                    $session_deleted =  $tokenController->deleteUserSessions($rowUser['id'], $db);

                    /** create a new session token */
                    $session_token =  $tokenController->createToken($token,$db);
                    if (!is_null($session_token) && !empty($session_token)) {

                        $response = sendUserJsonResponse("success", "Authentication Successful...", $decryptData, $session_token, 200);
                    } else {
                        $response = sendJsonResponse("failure", "There was an error in processing the token... Please Try Again...", 400);
                    }
                } else {
                    $response = sendJsonResponse("failure", "Passoword is Incorrect", 400);
                }
            } else {

                $response = sendJsonResponse("failure", "Invalid Input", 400);
            }
        } else if ($user_found == 0) {

            $response = sendJsonResponse("failure", "Invalid username", 400);
        }
        closeDb($db);
        $db =null;
        return $response;
    }
    
    
    public function getUserDetails($data)
    {
        $response = "";
        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $tokenController = new TokenController();
        $db = getDb();
        $crud = new Crud();


        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);

        if ($token_found === 1) {

            $stmt2 = $db->prepare("SELECT * FROM `users_v2` where id=:id");
            $stmt2->bindValue(':id', $user_id);
            $rowUser = $crud->getByCondition($stmt2);
            $decryptData = $this->decryptUser($rowUser);

            $response = sendDataWithListResponse("success", "The Candidate Details Found", $decryptData, 200);


        } else {
            $response = sendJsonResponse("failure", "The Token could not be found...", 400);
        }
        closeDb($db);
        $db = null;
        return $response;
    }




    /** put this in common class */
   private function decryptUser($rowUser)
    {

        $obj = new stdClass();

        $obj->email_id = $this->decrypt($rowUser['email_id']);
        $obj->mobile_number = $this->decrypt($rowUser['mobile_number']);
        $obj->first_name = $this->decrypt($rowUser['first_name']);
        $obj->last_name = $this->decrypt($rowUser['last_name']);

        $obj->id = $rowUser['id'];
        $obj->address = $rowUser['address'];
        $obj->city = $rowUser['city'];
        $obj->state = $rowUser['state'];
        $obj->pincode = $rowUser['pincode'];
        $obj->enabled_apps = $rowUser['enabled_apps'];
        $obj->email_verified = $rowUser['email_verified'];
        $obj->mobile_verified = $rowUser['mobile_verified'];
        $obj->qualification = $rowUser['qualification'];
        $obj->degree = $rowUser['degree'];
        $obj->experience =$rowUser['experience'];


        return $obj;
    }

    private function convertUserToJson(DecryptedData $decrypData)
    {

        $data = array(
            'id' => $decrypData->getId(),
            'mobile_number' => $decrypData->getMobileNumber(),
            'first_name' => $decrypData->getFirstName(),
            'last_name' => $decrypData->getLastName(),
            'address' => $decrypData->getAddress(),
            'city' => $decrypData->getCity(),
            'pincode' => $decrypData->getPincode(),
            'email_id' => $decrypData->getEmailId()

        );
        return $data;
    }

    private function decrypt($data)
    {
        //todo: put this in .env file....
        $decrypted_key = base64_decode(ENCRYPTION_KEY);
        $decrypted_iv = base64_decode(ENCRYPTION_IV);
        return openssl_decrypt($data, CIPHER, $decrypted_key, OPENSSL_RAW_DATA, $decrypted_iv);
    }
    
    
    
    public function updateProfileDetails($data)
    {
        //todo: implement this method...

        $response = "";
        $token = $data['session_token'];
        $user_id = $data['user_id'];
        $tokenController = new TokenController();
        $db = getDb();
        $crud = new Crud();

        $token_found = $tokenController->verifyTokenWithoutJsonResponse($token, $user_id, $db);;
        

        if ($token_found == 1) {
            

            $user = new User();
            $mob = $data['profile']['mobile_number'];
            $email = $data['profile']['email_id'];
            $fname = $data['profile']['first_name'];
            $lastname = $data['profile']['last_name'];
            $add = $data['profile']['address'];
            
            $user->setEmailId($email);
            $user->setMobileNumber($mob);
            $user->setUserName($mob);
            $user->setFirstName($fname);
            $user->setLastName($lastname);
            $user->setAddress($add);
            $user->setCity($data['profile']['city']);
            $user->setState($data['profile']['state']);
            $user->setQualification($data['profile']['qualification']);
            $user->setPincode($data['profile']['pincode']);
            $user->setDegree($data['profile']['degree']);
            $user->setExperience($data['profile']['experience']);
            // Encrypt the username to check
           // Encrypt the username to check
            $encrypted_username_indb = $user->getEncryptedMobileNumber();

            $find_user = $db->prepare("SELECT * FROM `users_v2`  WHERE username =:username");
            $find_user->bindValue(':username', $encrypted_username_indb);

            $user_found = $crud->findUserWithoutJson($find_user);
            

            if($user_found == 1){
                
                // set the data to the user model...
                // check if user already exists...
                // Encrypt the PII data and Save to database
                $encrypted_mobile = $user->getEncryptedMobileNumber();  // encrypted
                $encrypted_email = $user->getEncryptedEmailId();        // encrypted
                $encrypted_first_name = $user->getEncryptedFirstName(); // encrypted
                $encrypted_last_name = $user->getEncryptedLastName();   // encrypted

                $address =  $user->getAddress();
                $city = $user->getCity();
                $state = $user->getState();
                $pincode =  $user->getPincode();
                $qualification = $user->getQualification();
                $degree = $user->getDegree();
                $exp = $user->getExperience();
                
                $stmt = $db->prepare("UPDATE `users_v2` SET `first_name`='$encrypted_first_name', `last_name`='$encrypted_last_name', `address`='$address', `city`='$city', `state`='$state', `pincode`='$pincode', `qualification`='$qualification', `degree`='$degree', `experience`='$exp'  WHERE `id`='$user_id'");
                $result = $crud->update($stmt);

                $data = json_decode($result);

                if ($data->result == 'success') {
                    $stmt2 = $db->prepare("SELECT * FROM `users_v2` where id=:id");
                    $stmt2->bindValue(':id', $user_id);
                    $rowUser = $crud->getByCondition($stmt2);
                    $decryptData = $this->decryptUser($rowUser);
                    $response = sendDataWithListResponse("success", "The user details got updated successfully", $decryptData, 204);
                } else {
                    $response = sendJsonResponse("failure", "There was an error in updating the profile... Please Try Again...", 400);
                }
            } else {
                $response = sendJsonResponse("failure", "User doesn't exists with the provided details", 400);
            }
        } else {
            $response = sendJsonResponse("failure", "The Token could not be found...", 400);
        }

        closeDb($db);
        $db = null;
        return $response;
    }
}
