<?php

require_once '../model/SalesFreelancerJob.php'; // Fixed the model name to match file name
require_once '../database/Db.php';
require_once '../utils/Utils.php'; // Added Utils for response handling

class PostJobsController
{
    public function addSalesFreelancersJob($data)
    {
        $db = getDb(); // Open the database connection
        $response = "";

        try {
            $jobData = $data['sales_freelancers_job'];
            $job = new SalesFreelancersJob();
            $job->set($jobData); // Set the data using the model's `set` method

            // Prepare insert query for sales freelancers job
            $insertJobStatement = $db->prepare("INSERT INTO `sales_freelancers_job`(`brand_id`, `minimum_payout`, `maximum_payout`, `frequency_of_payment`, `work_start_date`, `work_end_date`)
            VALUES (:brand_id, :minimum_payout, :maximum_payout, :frequency_of_payment, :work_start_date, :work_end_date)");

            // Bind parameters
            $insertJobStatement->bindValue(':brand_id', $job->getBrandId());
            $insertJobStatement->bindValue(':minimum_payout', $job->getMinimumPayout());
            $insertJobStatement->bindValue(':maximum_payout', $job->getMaximumPayout());
            $insertJobStatement->bindValue(':frequency_of_payment', $job->getFrequencyOfPayment());
            $insertJobStatement->bindValue(':work_start_date', $job->getWorkStartDate());
            $insertJobStatement->bindValue(':work_end_date', $job->getWorkEndDate());

            // Execute the statement and check the result
            if ($insertJobStatement->execute()) {
                $response = sendJsonResponse(true, "Sales freelancers job added successfully.", 201);
            } else {
                $response = sendJsonResponse(false, "Failed to add sales freelancers job.", 400);
            }

        } catch (PDOException $e) {
            // Handle any errors
            $response = sendJsonResponse(false, "Error: " . $e->getMessage(), 500);
        }

        closeDb($db); // Close the database connection

        return $response; // Return the response
    }
}
