<?php

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */


define('SUCCESS', 'success');
define('FAILURE', 'failure');


function isValidMobileNumber($number)
{
    // Use regular expression to check if it's exactly 10 digits
    return preg_match('/^\d{10}$/', $number) === 1;
}


function isValidEmail($email)
{
    return filter_var($email, FILTER_VALIDATE_EMAIL) !== false;
}

function isValidPincode($number)
{
    // Use regular expression to check if it's exactly 6 digits
    return preg_match('/^\d{6}$/', $number) === 1;
}



function isValidPassword($password)
{
    // Define the criteria for a valid password
    $minLength = 8;
    $maxLength = 12;
    $hasUpperCase = preg_match('/[A-Z]/', $password);
    $hasLowerCase = preg_match('/[a-z]/', $password);
    $hasDigit = preg_match('/\d/', $password);
    $hasSpecialChar = preg_match('/[\W_]/', $password);

    // Check the length of the password
    $isLengthValid = strlen($password) >= $minLength && strlen($password) <= $maxLength;

    // Combine all the criteria
    $isValid = $isLengthValid && $hasUpperCase && $hasLowerCase && $hasDigit && $hasSpecialChar;

    return $isValid;
}


function sendJsonResponse($result, $message, $statusCode)
{
    http_response_code($statusCode);
    return json_encode(['result' => $result, 'message' => $message]);
}

function sendDataWithListResponse($result, $message, $list, $statusCode)
{
    http_response_code($statusCode);
    return json_encode(['result' => $result, 'message' => $message, 'data' => $list]);
}



function sendUserJsonResponse($result, $message, $user, $session_token, $statusCode)
{
    http_response_code($statusCode);
    return json_encode(['result' => $result, 'message' => $message, 'data' => $user, 'session_token' => $session_token]);
}


function sendJsonResponseWithParameter($result, $message, $id, $statusCode)
{
    http_response_code($statusCode);
    return json_encode(['result' => $result, 'message' => $message, 'id' => $id]);
}

function generateToken($length = 32)
{
    return bin2hex(random_bytes($length));
}




function isValidDateOfBirth($date, $format = 'Y-m-d')
{
    // Create a DateTime object from the input date
    $dob = DateTime::createFromFormat($format, $date);

    // Check if the date is valid
    $isValidFormat = $dob && $dob->format($format) === $date;

    if (!$isValidFormat) {
        return false;
    }

    // Get the current date
    $now = new DateTime();
    // Check if the date is not in the future
    if ($dob > $now) {
        return false;
    }

    // Calculate the age
    $age = $now->diff($dob)->y;

    // Check if the age is within a reasonable range (e.g., 0 to 18 to 58 years)
    if ($age >= 18 || $age <= 58) {
        return false;
    }

    return true;
}




function getMinusMonth($date, $minus)
{
    $minusMonth = "-" . $minus . " " . "month";
    $current_date = date("Y-m-d");

    $final_date = date("Y-m-d", strtotime($current_date . $minusMonth));

    return $final_date;
}


function getCurrentTime()
{
    date_default_timezone_set('Asia/Kolkata');
    $now = new DateTime();
    $current = $now->format('Y-m-d H:i:s');
    return $current;
}

function getTokenExpiryTime()
{

    date_default_timezone_set('Asia/Kolkata');
    $currentDate = new DateTime();
    // Add 4 days to the current date
    $currentDate->modify('+4 days');
    // Format the date to a readable string (optional)
    $formattedDate = $currentDate->format('Y-m-d H:i:s');
    return $formattedDate;
}


function getCurrentYear()
{
    date_default_timezone_set('Asia/Kolkata');
    $now = new DateTime();
    $current = $now->format('Y');
    return $current;
}

function getCurrentDate()
{
    date_default_timezone_set('Asia/Kolkata');
    $now = new DateTime();
    $current = $now->format('Y-m-d');
    return $current;
}

function generateAlphanemuric()
{
    $characters = 'abcdefghijklmnopqrstuvwxyz0123456789';
    $random_string_length = 1;
    $string = '';
    $max = strlen($characters) - 1;
    for ($i = 0; $i < $random_string_length; $i++) {
        $string .= $characters[mt_rand(0, $max)];
    }
    return $string;
}


function getAutoPassword()
{
    $data = '1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZabcefghijklmnopqrstuvwxyz';
    return substr(str_shuffle($data), 0, 7);
}

function validateSession($user_id, $sessionhash)
{

    $db = getDb();
    $stmt = $db->prepare("SELECT hash FROM users WHERE user_id=:user_id");
    $stmt->bindValue(':user_id', $user_id, PDO::PARAM_STR);
    $crud = new Crud();
    $row = $crud->getByCondition($stmt);
    extract($row);
    closeDb();

    if (strcmp($hash, $sessionhash) == 0) {
        return 1;
    } else {
        return 0;
    }
}




function getYearDifference($date1, $date2)
{

    $start = date_create($date1);
    $end = date_create($date2);
    $diff = date_diff($start, $end);
    return $diff->y;
}

