$(document).ready(function () {
    console.log('Document ready - fetching brands...');

    // Initially hide the location-related fields
    $('#yesNo').hide(); // Hide the location fields initially

    // Fetch Brand Names on Page Load
    $.ajax({
        type: "GET",
        url: "../sales_freelancer_app/api/SFBrandsapi.php",
        dataType: 'json',
        success: function (response) {
            console.log('Brand response:', response);

            var transactions = response.data;
            var options = '<option value="">Select Brand Name</option>';

            if (transactions && transactions.length > 0) {
                transactions.forEach(transaction => {
                    options += `<option value="${transaction.id}">${transaction.brand_name}</option>`;
                });
            }

            $('#brand').html(options);
        },
        error: function (jqXHR, textStatus, errorThrown) {
            console.error('Error fetching brands:', textStatus, errorThrown);
            Swal.fire('Error', 'Failed to load brand names.', 'error');
        }
    });

    // Fetch Assignments when a Brand is Selected
    $("#brand").change(function () {
        var brand_id = $(this).val();  
        console.log('Selected brand ID:', brand_id);

        if (!brand_id) {
            $('#assignment_name').html('<option value="">Select Assignment Name</option>');
            $('#activity_name').html('<option value="">Select Activity Name</option>');
            return;
        }

        $.ajax({
            type: "POST",
            url: "../sales_freelancer_app/api/SFAssignmentsListapi.php",
            dataType: 'json',
            data: JSON.stringify({ "brand_id": brand_id }),
            success: function (response) {
                console.log('Assignment response:', response);

                var transactions = response.data;
                var options = '<option value="">Select Assignment Name</option>';

                if (transactions && transactions.length > 0) {
                    transactions.forEach(transaction => {
                        options += `<option value="${transaction.id}">${transaction.assignment_name}</option>`;
                    });
                }

                $('#assignment_name').html(options);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                console.error('Error fetching assignments:', textStatus, errorThrown);
                Swal.fire('Error', 'Failed to load assignments.', 'error');
            }
        });
    });

    // Fetch Activities when an Assignment is Selected
    $("#assignment_name").change(function () {
        var assignment_id = $(this).val();  
        console.log('Selected assignment ID:', assignment_id);

        if (!assignment_id) {
            $('#activity_name').html('<option value="">Select Activity Name</option>');
            return;
        }

        $.ajax({
            type: "POST",
            url: "../sales_freelancer_app/api/SFGetActivity.php",
            dataType: 'json',
            data: JSON.stringify({ "assignment_id": assignment_id }),
            success: function (response) {
                console.log('Activity response:', response);

                var activities = response.data;
                var options = '<option value="">Select Activity Name</option>';

                if (activities && activities.length > 0) {
                    activities.forEach(activity => {
                        options += `<option value="${activity.id}">${activity.activity_name}</option>`;
                    });
                }

                $('#activity_name').html(options);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                console.error('Error fetching activities:', textStatus, errorThrown);
                Swal.fire('Error', 'Failed to load activities.', 'error');
            }
        });
    });

    // Handle the Create Auto Task radio button change
    $('input[name="yesNo"]').change(function() {
        if ($(this).val() == '1') { // Yes
            $('#yesNo').show(); // Show Task Location Same as Activity options
        } else { // No
            $('#yesNo').hide(); // Hide Task Location Same as Activity options
            // Reset selections if Auto Task is set to No
            $('input[name="activity_yesNo"]').prop('checked', false);
            $('#yesNo').find('input[type="text"]').val(''); // Clear input fields
        }
    });

    // Handle the Task Location Same as Activity radio button change
    $('input[name="activity_yesNo"]').change(function() {
        if ($(this).val() == '1') { // Yes
            // If "Yes" is selected, hide location fields
            $('#yesNo').hide();
        } else { // No
            // If "No" is selected, show location fields
            $('#yesNo').show(); // Show location fields for input
        }
    });

    $('#btn_register').click(function (e) {
        e.preventDefault(); 

        // Retrieve Form Data
        var brand = $('#brand').val().trim();
        var assignment_name = $('#assignment_name').val().trim();
        var activity_name = $('#activity_name').val().trim();
        var location = $('#activity_location').val().trim(); // Get the location
        var area = $('#area').val().trim(); // Get the area
        var pincode = $('#pincode').val().trim();
        var error_count = 0;

        // Form Validation
        if (brand === '') {
            $("#brand").css('border-color', 'red');
            $('#err_brand').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#brand").css('border-color', 'green');
            $('#err_brand').html('');
        }

        if (assignment_name === '') {
            $("#assignment_name").css('border-color', 'red');
            $('#err_assignment_name').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#assignment_name").css('border-color', 'green');
            $('#err_assignment_name').html('');
        }

        if (activity_name === '') {
            $("#activity_name").css('border-color', 'red');
            $('#err_activity_name').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#activity_name").css('border-color', 'green');
            $('#err_activity_name').html('');
        }

        // Validate location fields only if Task Location Same as Activity is "No"
        if ($('input[name="activity_yesNo"]:checked').val() == '0') {
            if (location === '') {
                $("#activity_location").css('border-color', 'red');
                $('#err_activity_location').html('This Field is Mandatory');
                error_count++;
            } else {
                $("#activity_location").css('border-color', 'green');
                $('#err_activity_location').html('');
            }

            if (pincode === '') {
                $("#pincode").css('border-color', 'red');
                $('#err_pincode').html('This Field is Mandatory');
                error_count++;
            } else if (!/^\d{6}$/.test(pincode)) {
                $("#pincode").css('border-color', 'red');
                $('#err_pincode').html('Pincode Must Be In 6 Digits Only');
                error_count++;
            } else {
                $("#pincode").css('border-color', 'green');
                $('#err_pincode').html('');
            }

            if (area === '') {
                $("#area").css('border-color', 'red');
                $('#err_area').html('This Field is Mandatory');
                error_count++;
            } else {
                $("#area").css('border-color', 'green');
                $('#err_area').html('');
            }
        }

        if (error_count === 0) {
            var formValues = {
                brand_id: brand,
                sf_assignment_id: assignment_name,
                sf_activity_id: activity_name,
                location: location,
                area: area,
                pincode: pincode
            };

            var json = JSON.stringify(formValues);
            console.log(json);

            $.ajax({
                type: "POST",
                url: "../sales_freelancer_app/api/UserAssignmentsapi.php",
                data: json,
                contentType: 'application/json',
                dataType: 'json',
                success: function (response) {
                    console.log('Response from server:', response); 
                    if (response.success) {
                        $('#assignment_to_user_form').hide();  
                        Swal.fire({
                            title: "Assignment To Users Created Successfully!",
                            confirmButtonColor: "#713DAD",
                            confirmButtonText: "OK"
                        });
                    } else {
                        Swal.fire({
                            title: response.message || "Submission failed!",
                            confirmButtonColor: "#713DAD",
                            confirmButtonText: "OK"
                        });
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    console.error('AJAX Error:', textStatus, errorThrown);
                    console.error('Response:', jqXHR.responseText);
                    Swal.fire('Error', 'Failed to register Assignment to Users. ' + jqXHR.responseText, 'error');
                }
            });
        } else {
            $('#status').html(error_count + ' fields are incorrect. Kindly fill all details properly');
        }
    });
});
