$(function () {
    'use strict';

    // Register the ChartDataLabels plugin
    Chart.register(ChartDataLabels);

    // Chart Data for Registrations, Attendance, Nielet, Feedback
    const cs_registrations_data = {
        labels: ["2023", "2024"],
        datasets: [{ data: [12, 7], backgroundColor: ['#FFCC99', '#FFCC99'] }]
    };
    const cs_attendance_data = {
        labels: ["2023", "2024"],
        datasets: [{ data: [5, 10], backgroundColor: ['#CC6600', '#CC6600'] }]
    };
    const cs_nielet_data = {
        labels: ["2023", "2024"],
        datasets: [{ data: [8, 6], backgroundColor: ['#FF99CC', '#FF99CC'] }]
    };
    const cs_feedback_data = {
        labels: ["2023", "2024"],
        datasets: [{ data: [13, 17], backgroundColor: ['#CC0066', '#CC0066'] }]
    };

    // Chart Options for each chart
    const commonOptions = {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            legend: { display: false },
            tooltip: { enabled: true },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: { weight: 'bold' }
            }
        },
        scales: {
            y: { beginAtZero: true, grace: '20%' }
        },
    };

    // Initialize chart instances
    const chartInstances = {};
    function initializeChart(chartId, chartType, chartData, chartOptions) {
        const ctx = $(chartId).get(0).getContext("2d");
        return new Chart(ctx, {
            type: chartType,
            data: chartData,
            options: chartOptions
        });
    }

    // Initialize the charts if their elements exist
    if ($("#cs_registrations").length) {
        chartInstances["cs_registrations"] = initializeChart("#cs_registrations", 'bar', cs_registrations_data, commonOptions);
    }
    if ($("#cs_attendance").length) {
        chartInstances["cs_attendance"] = initializeChart("#cs_attendance", 'bar', cs_attendance_data, commonOptions);
    }
    if ($("#cs_nielet").length) {
        chartInstances["cs_nielet"] = initializeChart("#cs_nielet", 'bar', cs_nielet_data, commonOptions);
    }
    if ($("#cs_feedback").length) {
        chartInstances["cs_feedback"] = initializeChart("#cs_feedback", 'bar', cs_feedback_data, commonOptions);
    }

    // (State-wise)
    const stateData = {
        labels: ['Tamil Nadu', 'Karnataka', 'Maharashtra', 'West Bengal', 'Gujarat'],
        datasets: [{
            label: 'Number of Assignments',
            data: [50, 30, 20, 40, 25],
            backgroundColor: ['#CC99FF', '#00CCCC', '#33FF99', '#FF66B2', '#FFB266'],
            borderWidth: 1
        }]
    };

    // (District-wise for each state)
    const districtData = {
        'Tamil Nadu': { labels: ['Chennai', 'Coimbatore', 'Madurai'], data: [10, 20, 20] },
        'Karnataka': { labels: ['Bangalore', 'Mysore', 'Hubli-Dharwad'], data: [15, 10, 5] },
        'Maharashtra': { labels: ['Mumbai', 'Pune', 'Nagpur'], data: [7, 8, 5] },
        'West Bengal': { labels: ['Kolkata', 'Howrah', 'Siliguri'], data: [12, 15, 13] },
        'Gujarat': { labels: ['Ahmedabad', 'Surat', 'Vadodara'], data: [10, 7, 8] }
    };

    // Pie Chart for State-wise Data
    const ctxPie = document.getElementById('statewise_data').getContext('2d');
    const statewiseChart = new Chart(ctxPie, {
        type: 'pie',
        data: stateData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: { display: true, position: 'right', labels: { boxWidth: 18 } },
                datalabels: {
                    anchor: 'center',
                    align: 'center',
                    color: '#000',
                    font: { weight: 'bold' },
                    formatter: value => value
                },
                tooltip: { enabled: true }
            },
            onClick: (event, elements) => {
                if (elements.length > 0) {
                    const index = elements[0].index;
                    const stateName = stateData.labels[index];
                    loadDoughnutChart(stateName);
                }
            }
        }
    });

    function loadDoughnutChart(stateName) {
        const districtInfo = districtData[stateName];
        document.getElementById('chart2Title').innerText = `${stateName} Data`;
        // console.log(`Loading doughnut chart for: ${stateName}`);
        console.log(districtInfo);
       
        // car visible
        const districtChartCard = document.getElementById('districtChartCard');
        if (districtChartCard) {
            districtChartCard.style.display = 'block'; 
        } else {
            console.error('District Chart Card not found.');
        }
        
        // Destroy existing chart 
        if (window.doughnutChart) {
            window.doughnutChart.destroy();
        }
        
        // Create new doughnut chart
        const ctxDoughnut = document.getElementById('districtwise_data').getContext('2d');
        window.doughnutChart = new Chart(ctxDoughnut, {
            type: 'doughnut',
            data: {
                labels: districtInfo.labels,
                datasets: [{
                    data: districtInfo.data,
                    backgroundColor: ['#CC99FF', '#00CCCC', '#FF66B2',]
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: true,
                        position: 'right',
                        labels: { boxWidth: 18 }
                    },
                    datalabels: {
                        color: '#000',
                        font: { weight: 'bold', size: 13 }
                    }
                }
            }
        });
        
        window.doughnutChart.resize();
    }
    
    loadDoughnutChart('Tamil Nadu');

    
});
