$(document).ready(function() {
    // State-wise and district-wise data
    const stateWiseData = {
        labels: ['State 1', 'State 2', 'State 3', 'State 4', 'State 5'],
        data: [300, 150, 200, 100, 250],
        districts: {
            'State 1': ['District 1A', 'District 1B', 'District 1C'],
            'State 2': ['District 2A', 'District 2B', 'District 2C'],
            'State 3': ['District 3A', 'District 3B'],
            'State 4': ['District 4A', 'District 4B', 'District 4C', 'District 4D'],
            'State 5': ['District 5A', 'District 5B']
        },
        districtData: {
            'State 1': [100, 100, 100],
            'State 2': [50, 50, 50],
            'State 3': [80, 120],
            'State 4': [30, 40, 20, 10],
            'State 5': [70, 180]
        }
    };

    // Initialize Pie Chart
    const ctx1 = document.getElementById('statewise_data').getContext('2d');
    const statewiseDataChart = new Chart(ctx1, {
        type: 'pie',
        data: {
            labels: stateWiseData.labels,
            datasets: [{
                label: 'State Data',
                data: stateWiseData.data,
                backgroundColor: ['#FF6384', '#36A2EB', '#FFCE56', '#FF9F40', '#4BC0C0'],
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'top',
                },
                datalabels: {
                    anchor: 'end',
                    align: 'end',
                },
            },
        }
    });

    // Initialize Doughnut Chart
    const ctx2 = document.getElementById('districtwise_data').getContext('2d');
    const districtwiseDataChart = new Chart(ctx2, {
        type: 'doughnut',
        data: {
            labels: [], // Will be populated dynamically
            datasets: [{
                label: 'District Data',
                data: [], // Will be populated dynamically
                backgroundColor: ['#FF6384', '#36A2EB', '#FFCE56', '#FF9F40', '#4BC0C0'],
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'top',
                },
                datalabels: {
                    anchor: 'end',
                    align: 'end',
                },
            },
        }
    });

    // Click event for Pie Chart
    statewiseDataChart.canvas.parentNode.onclick = function(evt) {
        const activePoints = statewiseDataChart.getElementsAtEventForMode(evt, 'nearest', { intersect: true }, false);
        if (activePoints.length) {
            const clickedElementIndex = activePoints[0].index;
            const stateLabel = stateWiseData.labels[clickedElementIndex];

            // Update Doughnut Chart with corresponding district data
            updateDistrictChart(stateLabel);
        }
    };

    // Function to update Doughnut Chart
    function updateDistrictChart(stateLabel) {
        districtwiseDataChart.data.labels = stateWiseData.districts[stateLabel]; // Set district labels
        districtwiseDataChart.data.datasets[0].data = stateWiseData.districtData[stateLabel]; // Set corresponding data
        districtwiseDataChart.update(); // Refresh the chart
    }
});
