// Manually register the Chart.js DataLabels plugin
Chart.register(ChartDataLabels);

// Data for Bar Chart (Top 5 Cities)
const cityData = {
    labels: ['Chennai', 'Delhi', 'Bangalore', 'Mumbai', 'Hyderabad'],
    datasets: [{
        label: 'Number of Assignments',
        data: [43, 30, 25, 33, 21],
        backgroundColor: ['#FF9999', '#FF9999', '#FF9999', '#FF9999', '#FF9999'],
        borderWidth: 1
    }]
};

// Data for Doughnut Charts (Top 5 Areas in Each City)
const areaData = {
    'Chennai': { 
        labels: ['Perungudi', 'Velachery', 'Adyar', 'Tambaram', 'Guindy'], 
        data: [10, 8, 6, 12, 7] 
    },
    'Delhi': { 
        labels: ['Connaught Place', 'Karol Bagh', 'Lajpat Nagar', 'Saket', 'Dwarka'], 
        data: [6, 7, 5, 9, 3] 
    },
    'Bangalore': { 
        labels: ['Whitefield', 'Koramangala', 'Indiranagar', 'Electronic City', 'Jayanagar'], 
        data: [4, 5, 3, 7, 6] 
    },
    'Mumbai': { 
        labels: ['Andheri', 'Bandra', 'Dadar', 'Goregaon', 'Borivali'], 
        data: [7, 4, 8, 9, 5] 
    },
    'Hyderabad': { 
        labels: ['Banjara Hills', 'Hitech City', 'Jubilee Hills', 'Madhapur', 'Secunderabad'], 
        data: [3, 2, 5, 6, 4] 
    }
};

// Data for Last 5 Days Leads
const leadsData = {
    labels: ['Day 1', 'Day 2', 'Day 3', 'Day 4', 'Day 5'],
    datasets: [{
        label: 'Leads',
        data: [47, 73, 60, 80, 93], 
        backgroundColor: '#FF66FF',
        borderWidth: 1
    }]
};

const chartInstances = {};

// Bar Chart for Top 5 Cities
const ctx1 = document.getElementById('chart1').getContext('2d');
chartInstances["chart1"] = new Chart(ctx1, {
    type: 'bar',
    data: cityData,
    options: {
        responsive: true,
        maintainAspectRatio: false, 
        plugins: {
            legend: { display: false },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: { weight: 'bold' },
                formatter: value => value
            },
            tooltip: { enabled: true }
        },
        scales: {
            y: {
                beginAtZero: true,
                grace: '20%', 
                ticks: {
                    z: 1, 
                },
            },
        },
        onClick: (event, elements) => {
            if (elements.length > 0) {
                const index = elements[0].index;
                const cityName = cityData.labels[index];
                loadDoughnutChart(cityName);
                updateMap(cityName); // Add this line to update the map
            }
        }
    }
});

// Load Doughnut Chart for Selected City
function loadDoughnutChart(cityName) {
    const areaInfo = areaData[cityName];
    document.getElementById('chart2Title').innerText = `Top 5 Assignments by ${cityName}`;

    if (window.doughnutChart) {
        window.doughnutChart.destroy();
    }

    document.getElementById('chart2Card').style.display = 'block';

    const ctx2 = document.getElementById('chart2').getContext('2d');
    window.doughnutChart = new Chart(ctx2, {
        type: 'doughnut',
        data: {
            labels: areaInfo.labels,
            datasets: [{
                data: areaInfo.data,
                backgroundColor: ['#FFB266', '#CC6600', '#B266FF', '#CC00CC', '#FF99CC']
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false, 
            plugins:{
                legend: 
                {
                    display: true,
                    position: 'right',
                    labels: { boxWidth: 18 }
                },
                datalabels: {
                    color: '#000',
                    font: {
                        weight: 'bold', 
                        size: 13 
                    }
                }
            }
        }
    });

        // Force chart to resize
        window.doughnutChart.resize();
}

// Initially Shows Chennai
loadDoughnutChart ('Chennai');

// Bar Chart for Last 5 Days Leads
const ctxLeads = document.getElementById('leadsChart').getContext('2d');
const leadsChart = new Chart(ctxLeads, {
    type: 'bar', 
    data: leadsData,
    options: {
        responsive: true,
        maintainAspectRatio: false,
        indexAxis: 'y', // This makes the bar chart horizontal
        plugins: {
            legend: { display: true },
            tooltip: { enabled: true },
            datalabels: {
                anchor: 'end',  
                align: 'right', 
                color: '#000',  
                font: { weight: 'bold', size: 12 },
                formatter: (value) => value, 
            }
        },
        scales: {
            x: {
                beginAtZero: true,
                grace: '10%', 
                ticks: {
                    z: 1, 
                },
            },
        },
    },
});


// Data for Freelancer By City and Area
const freelancerByCityData = {
    labels: ['Chennai', 'Delhi', 'Bangalore', 'Mumbai', 'Hyderabad'],
    datasets: [{
        label: 'Number of Freelancers',
        data: [25, 37, 21, 30, 18],
        backgroundColor: ['#99CCFF', '#99CCFF', '#99CCFF', '#99CCFF', '#99CCFF'],
        borderWidth: 1
    }]
};

// Area Data for Freelancers
const freelancerByAreaData = {
    'Chennai': { 
        labels: ['Perungudi', 'Velachery', 'Adyar', 'Tambaram', 'Guindy'], 
        data: [4, 5, 3, 7, 6] 
    },
    'Delhi': { 
        labels: ['Connaught Place', 'Karol Bagh', 'Lajpat Nagar', 'Saket', 'Dwarka'], 
        data: [5, 9, 11, 8, 4] 
    },
    'Bangalore': { 
        labels: ['Whitefield', 'Koramangala', 'Indiranagar', 'Electronic City', 'Jayanagar'], 
        data: [3, 2, 5, 6, 4] 
    },
    'Mumbai': { 
        labels: ['Andheri', 'Bandra', 'Dadar', 'Goregaon', 'Borivali'], 
        data: [6, 7, 5, 9, 3] 
    },
    'Hyderabad': { 
        labels: ['Banjara Hills', 'Hitech City', 'Jubilee Hills', 'Madhapur', 'Secunderabad'], 
        data: [2, 3, 2, 4, 6] 
    }
};

// Bar Chart for Freelancer By City
const ctxCity = document.getElementById('sf_city').getContext('2d');
const freelancerCityChart = new Chart(ctxCity, {
    type: 'bar',
    data: freelancerByCityData,
    options: {
        responsive: true,
        maintainAspectRatio: false, 
        plugins: {
            legend: { display: false },
            datalabels: {
                anchor: 'end',
                align: 'top',
                color: '#000',
                font: { weight: 'bold' },
                formatter: value => value
            },
            tooltip: { enabled: true }
        },
        scales: {
            y: {
                beginAtZero: true,
                grace: '20%', 
                ticks: {
                    z: 1, 
                },
            },
        },
        onClick: (event, elements) => {
            if (elements.length > 0) {
                const index = elements[0].index;
                const cityName = freelancerByCityData.labels[index];
                updateFreelancerAreaChart(cityName);
                updateMap(cityName); // Add this line to update the map
            }
        }
    }
});

// Freelancer By Area Chart
function updateFreelancerAreaChart(cityName) {
    const areaInfo = freelancerByAreaData[cityName];
    const ctxArea = document.getElementById('sf_area').getContext('2d');

    if (window.freelancerAreaChart) {
        window.freelancerAreaChart.destroy();
    }

    window.freelancerAreaChart = new Chart(ctxArea, {
        type: 'bar',
        data: {
            labels: areaInfo.labels,
            datasets: [{
                label: 'Number of Freelancers',
                data: areaInfo.data,
                backgroundColor: ['#9933FF', '#9933FF', '#9933FF', '#9933FF', '#9933FF'],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false, 
            plugins: {
                legend: { display: false },
                datalabels: {
                    anchor: 'end',
                    align: 'top',
                    color: '#000',
                    font: { weight: 'bold' },
                    formatter: value => value
                },
                tooltip: { enabled: true }
            },
            scales: {
                y: {
                    beginAtZero: true,
                    grace: '20%', 
                    ticks: {
                        z: 1, 
                    },
                },
            },
        }
    });
}

// Initially Shows Chennai
updateFreelancerAreaChart('Chennai');

// Initialize the map
const map = L.map('mapdiv').setView([12.9827, 80.1107], 12); // Centered on Chennai

// Add OpenStreetMap tiles
L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
    maxZoom: 12,
    attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
}).addTo(map);

// Define the locations of the areas
const areas = {
    'Tambaram': [12.9162, 80.1595],
    'Guindy': [13.0076, 80.2235],
    'Perungudi': [12.9257, 80.2297],
    'Velachery': [12.9673, 80.2156],
    'Adyar': [13.0058, 80.2515]
};

// Add markers for each area
for (const [name, coords] of Object.entries(areas)) {
    L.marker(coords)
        .addTo(map)
        .bindPopup(`This is ${name}!`)
        .openPopup();
}
