$(document).ready(function () {
    console.log('Document ready - fetching brands...');

    // Fetch Brand Names on Page Load
    $.ajax({
        type: "GET",
        url: "../sales_freelancer_app/api/SFBrandsapi.php",
        dataType: 'json',
        success: function (response) {
            console.log('Brand response:', response);  

            var transactions = response.data;  
            var options = '<option value="">Select Brand Name</option>';

            if (transactions && transactions.length > 0) {
                transactions.forEach(transaction => {
                    options += `<option value="${transaction.id}">${transaction.brand_name}</option>`;
                });
            }

            $('#brand').html(options);
        },
        error: function (jqXHR, textStatus, errorThrown) {
            console.error('Error fetching brands:', textStatus, errorThrown);
            Swal.fire('Error', 'Failed to load brand names.', 'error');
        }
    });

    // Fetch Assignments when a Brand is Selected
    $("#brand").change(function () {
        var brand_id = $(this).val(); 
        console.log('Selected brand ID:', brand_id);

        if (!brand_id) {
            $('#assignment_name').html('<option value="">Select Assignment Name</option>');
            return;
        }

        $.ajax({
            type: "POST",
            url: "../sales_freelancer_app/api/SFAssignmentsListapi.php",
            dataType: 'json',
            data: JSON.stringify({ "brand_id": brand_id }),
            success: function (response) {
                console.log('Assignment response:', response);  
                
                var transactions = response.data;  
                var options = '<option value="">Select Assignment Name</option>';

                if (transactions && transactions.length > 0) {
                    transactions.forEach(transaction => {
                        options += `<option value="${transaction.id}">${transaction.assignment_name}</option>`;
                    });
                }

                $('#assignment_name').html(options);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                console.error('Error fetching assignments:', textStatus, errorThrown);
                Swal.fire('Error', 'Failed to load assignments.', 'error');
            }
        });
    });

    $('#btn_register').click(function (e) {
        e.preventDefault(); 

        // Retrieve Form Data
        var brand = $('#brand').val().trim();
        var assignment_name = $('#assignment_name').val().trim();
        var activity_name = $('#activity_name').val().trim();
        var activity_location = $('#activity_location').val().trim();
        var start_date = $('#start_date').val().trim();
        var end_date = $('#end_date').val().trim();
        var start_time = $('#start_time').val().trim();
        var end_time = $('#end_time').val().trim();
        var activity_desc = $('#activity_desc').val().trim();
        var lms_category = $('#lms_category').val().trim();
        var pincode = $('#pincode').val().trim();
        var error_count = 0;

        // Form Validation
        if (brand === '') {
            $("#brand").css('border-color', 'red');
            $('#err_brand').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#brand").css('border-color', 'green');
            $('#err_brand').html('');
        }

        if (activity_name === '') {
            $("#activity_name").css('border-color', 'red');
            $('#err_activity_name').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#activity_name").css('border-color', 'green');
            $('#err_activity_name').html('');
        }

        if (start_date === '') {
            $("#start_date").css('border-color', 'red');
            $('#err_start_date').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#start_date").css('border-color', 'green');
            $('#err_start_date').html('');
        }

        if (end_date === '') {
            $("#end_date").css('border-color', 'red');
            $('#err_end_date').html('This Field is Mandatory');
            error_count++;
        } else if (new Date(end_date) <= new Date(start_date)) {
            $("#end_date").css('border-color', 'red');
            $('#err_end_date').html('End date must be greater than start date');
            error_count++;
        } else {
            $("#end_date").css('border-color', 'green');
            $('#err_end_date').html('');
        }

        if (start_time === '') {
            $("#start_time").css('border-color', 'red');
            $('#err_start_time').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#start_time").css('border-color', 'green');
            $('#err_start_time').html('');
        }

        if (end_time === '') {
            $("#end_time").css('border-color', 'red');
            $('#err_end_time').html('This Field is Mandatory');
            error_count++;
        } else if (start_time !== '' && end_time !== '' && start_time >= end_time) {
            $("#end_time").css('border-color', 'red');
            $('#err_end_time').html('End time must be greater than start time');
            error_count++;
        } else {
            $("#end_time").css('border-color', 'green');
            $('#err_end_time').html('');
        }

        if (pincode === '' || pincode.length !== 6 || !/^\d{6}$/.test(pincode)) {
            $("#pincode").css('border-color', 'red');
            $('#err_pincode').html('Pincode must be exactly 6 digits');
            error_count++;
        } else {
            $("#pincode").css('border-color', 'green');
            $('#err_pincode').html('');
        }

        if (error_count === 0) {
            var formValues = {
                brand_id: brand,
                assignment_id : assignment_name,
                activity_name: activity_name,
                location: activity_location,
                start_date: start_date,
                end_date: end_date,
                start_time: start_time,
                end_time: end_time,
                activity_description: activity_desc,
                lms_category: lms_category,
                pincode: pincode
            };


            var json = JSON.stringify(formValues);
            // console.log(json);
            uploadFile(json);

        } else {
            $('#status').html(error_count + ' fields are incorrect. Kindly fill all details properly');
        }

    });
});

async function uploadFile(json) {
    let formData = new FormData();
    formData.append("json_data", json);
    console.log($('input[type=file]')[0].files[0])
    const fileInput = $('input[type=file]')[0];
    if (fileInput.files.length > 0) {
        formData.append("uploaded_file[]", fileInput.files[0]);
    }

    try {
        let response = await fetch('../sales_freelancer_app/api/SFActivityApi_new.php', {
            method: "POST",
            body: formData
        });

        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }

        let response_json = await response.json();
        console.log(response_json);

        if (response_json.success) {
            $('#activityForm').hide();  
            Swal.fire({
                title: "Activity Created Successfully!",
                confirmButtonColor: "#713DAD",
                confirmButtonText: "OK"
            });
        } else {
            Swal.fire({
                title: response_json.message || "Submission failed!",
                confirmButtonColor: "#713DAD",
                confirmButtonText: "OK"
            });
        }
    } catch (error) {
        console.error('Error during upload:', error);
        Swal.fire('Error', 'Failed to upload document.', 'error');
    }
}



            // $.ajax({
            //     type: "POST",
            //     url: "../sales_freelancer_app/api/SFActivityApi.php",
            //     data: json,
            //     contentType: 'application/json',
            //     dataType: 'json',
            //     success: function (response) {
            //         console.log('Response from server:', response); // Check response structure
            //         if (response.success) {
            //             $('#activityForm').hide();  
            //             Swal.fire({
            //                 title: "Activity Created Successfully!",
            //                 confirmButtonColor: "#713DAD",
            //                 confirmButtonText: "OK"
            //             });
            //         } else {
            //             Swal.fire({
            //                 title: response.message || "Submission failed!",
            //                 confirmButtonColor: "#713DAD",
            //                 confirmButtonText: "OK"
            //             });
            //         }
            //     },
                
            //     error: function (jqXHR, textStatus, errorThrown) {
            //         console.error('AJAX Error:', textStatus, errorThrown);
            //         console.error('Response:', jqXHR.responseText);
            //         Swal.fire('Error', 'Failed to register activity. ' + jqXHR.responseText, 'error');
            //     }
            // });
        // } else {
        //     $('#status').html(error_count + ' fields are incorrect. Kindly fill all details properly');
        // }
//     });
// });



async function uploadFile(json) {
    // let json_parse = JSON.parse(json);
    let formData = new FormData;
    formData.append("json_data", json);
    formData.append("uploaded_file[]", $('input[type=file]')[0].files[0]);
    console.log($('input[type=file]')[0].files[0])
    var response = await fetch('../sales_freelancer_app/api/SFActivityApi_new.php', {
        method: "POST",
        body: formData
    });
    var response_json = await response.json()
    console.log(response_json);
    if (response_json.success) {
        $('#activityForm').hide();  
        Swal.fire({
            title: "Activity Created Successfully!",
            confirmButtonColor: "#713DAD",
            confirmButtonText: "OK"
        });
    } else {
        Swal.fire({
            title: response_json.message || "Submission failed!",
            confirmButtonColor: "#713DAD",
            confirmButtonText: "OK"
        });
    }

}










// header('Content-Type: application/json');

// if ($_SERVER['REQUEST_METHOD'] === 'POST') {
//     $json_data = $_POST['json_data'] ?? null;
//     if ($json_data) {
//         $data = json_decode($json_data, true);

//         if (isset($_FILES['uploaded_file']) && $_FILES['uploaded_file']['error'] == UPLOAD_ERR_OK) {
//             $uploaded_file = $_FILES['uploaded_file'];
//         } else {
//             echo json_encode(['success' => false, 'message' => 'File upload failed.']);
//             exit;
//         }

//         echo json_encode(['success' => true, 'message' => 'Activity created successfully!']);
//     } else {
//         echo json_encode(['success' => false, 'message' => 'No data received.']);
//     }
// } else {
//     echo json_encode(['success' => false, 'message' => 'Invalid request method.']);
// }



