$(document).ready(function () {
    console.log('Document ready - fetching brands...');

    // Fetch Brand Names on Page Load
    $.ajax({
        type: "GET",
        url: "../sales_freelancer_app/api/SFBrandsapi.php",
        dataType: 'json',
        success: function (response) {
            console.log('Brand response:', response);

            var transactions = response.data;
            var options = '<option value="">Select Brand Name</option>';

            if (transactions && transactions.length > 0) {
                transactions.forEach(transaction => {
                    options += `<option value="${transaction.id}">${transaction.brand_name}</option>`;
                });
            }

            $('#brand').html(options);
        },
        error: function (jqXHR, textStatus, errorThrown) {
            console.error('Error fetching brands:', textStatus, errorThrown);
            Swal.fire('Error', 'Failed to load brand names.', 'error');
        }
    });

    // Fetch Assignments when a Brand is Selected
    $("#brand").change(function () {
        var brand_id = $(this).val();  
        console.log('Selected brand ID:', brand_id);

        if (!brand_id) {
            $('#assignment_name').html('<option value="">Select Assignment Name</option>');
            $('#activity_name').html('<option value="">Select Activity Name</option>');
            return;
        }

        $.ajax({
            type: "POST",
            url: "../sales_freelancer_app/api/SFAssignmentsListapi.php",
            dataType: 'json',
            data: JSON.stringify({ "brand_id": brand_id }),
            success: function (response) {
                console.log('Assignment response:', response);

                var transactions = response.data;
                var options = '<option value="">Select Assignment Name</option>';

                if (transactions && transactions.length > 0) {
                    transactions.forEach(transaction => {
                        options += `<option value="${transaction.id}">${transaction.assignment_name}</option>`;
                    });
                }

                $('#assignment_name').html(options);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                console.error('Error fetching assignments:', textStatus, errorThrown);
                Swal.fire('Error', 'Failed to load assignments.', 'error');
            }
        });
    });

    // Fetch Activities when an Assignment is Selected
    $("#assignment_name").change(function () {
        var assignment_id = $(this).val();  
        console.log('Selected assignment ID:', assignment_id);

        if (!assignment_id) {
            $('#activity_name').html('<option value="">Select Activity Name</option>');
            return;
        }

        $.ajax({
            type: "POST",
            url: "../sales_freelancer_app/api/SFGetActivity.php",  // Update the API endpoint if needed
            dataType: 'json',
            data: JSON.stringify({ "assignment_id": assignment_id }),
            success: function (response) {
                console.log('Activity response:', response);

                var activities = response.data;
                var options = '<option value="">Select Activity Name</option>';

                if (activities && activities.length > 0) {
                    activities.forEach(activity => {
                        options += `<option value="${activity.id}">${activity.activity_name}</option>`;
                    });
                }

                $('#activity_name').html(options);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                console.error('Error fetching activities:', textStatus, errorThrown);
                Swal.fire('Error', 'Failed to load activities.', 'error');
            }
        });
    });

    
    $('#btn_register').click(function (e) {
        e.preventDefault(); 

        // Retrieve Form Data
        var brand = $('#brand').val().trim();
        var assignment_name = $('#assignment_name').val().trim();
        var activity_name = $('#activity_name').val().trim();
        var task_name = $('#task_name').val().trim();
        var start_date = $('#start_date').val().trim();
        var end_date = $('#end_date').val().trim();
        var task_desc = $('#task_desc').val().trim();
        var error_count = 0;

        // Form Validation
        if (brand === '') {
            $("#brand").css('border-color', 'red');
            $('#err_brand').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#brand").css('border-color', 'green');
            $('#err_brand').html('');
        }

        if (start_date === '') {
            $("#start_date").css('border-color', 'red');
            $('#err_start_date').html('This Field is Mandatory');
            error_count++;
        } else {
            $("#start_date").css('border-color', 'green');
            $('#err_start_date').html('');
        }

        if (end_date === '') {
            $("#end_date").css('border-color', 'red');
            $('#err_end_date').html('This Field is Mandatory');
            error_count++;
        } else if (new Date(end_date) <= new Date(start_date)) {
            $("#end_date").css('border-color', 'red');
            $('#err_end_date').html('End date must be greater than start date');
            error_count++;
        } else {
            $("#end_date").css('border-color', 'green');
            $('#err_end_date').html('');
        }

        if (error_count === 0) {
            var formValues = {
                brand_id: brand,
                sf_assignment_id: assignment_name,
                sf_activity_id: activity_name,
                task_name: task_name,
                start_date: start_date,
                end_date: end_date,
                task_description: task_desc,
                // created_by: user_id
            };

            var json = JSON.stringify(formValues);
            console.log(json);

            $.ajax({
                type: "POST",
                url: "../sales_freelancer_app/api/SFTaskApi.php",
                data: json,
                contentType: 'application/json',
                dataType: 'json',
                success: function (response) {
                    console.log('Response from server:', response); 
                    if (response.success) {
                        $('#task_form').hide();  
                        Swal.fire({
                            title: "Task Created Successfully!",
                            confirmButtonColor: "#713DAD",
                            confirmButtonText: "OK"
                        });
                    } else {
                        Swal.fire({
                            title: response.message || "Submission failed!",
                            confirmButtonColor: "#713DAD",
                            confirmButtonText: "OK"
                        });
                    }
                },
                
                error: function (jqXHR, textStatus, errorThrown) {
                    console.error('AJAX Error:', textStatus, errorThrown);
                    console.error('Response:', jqXHR.responseText);
                    Swal.fire('Error', 'Failed to register Task. ' + jqXHR.responseText, 'error');
                }
            });
        } else {
            $('#status').html(error_count + ' fields are incorrect. Kindly fill all details properly');
        }
    });
});
